"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from ._schema0 import Schema0, Schema0Enum, Schema0TypedDict
    from ._schema3 import (
        Schema3,
        Schema3ReasoningEncrypted,
        Schema3ReasoningEncryptedTypedDict,
        Schema3ReasoningSummary,
        Schema3ReasoningSummaryTypedDict,
        Schema3ReasoningText,
        Schema3ReasoningTextTypedDict,
        Schema3TypedDict,
        Schema5,
    )
    from .activityitem import ActivityItem, ActivityItemTypedDict
    from .assistantmessage import (
        AssistantMessage,
        AssistantMessageContent,
        AssistantMessageContentTypedDict,
        AssistantMessageTypedDict,
    )
    from .badgatewayresponseerrordata import (
        BadGatewayResponseErrorData,
        BadGatewayResponseErrorDataTypedDict,
    )
    from .badrequestresponseerrordata import (
        BadRequestResponseErrorData,
        BadRequestResponseErrorDataTypedDict,
    )
    from .chatcompletionfinishreason import ChatCompletionFinishReason
    from .chaterror import ChatErrorError, ChatErrorErrorTypedDict, Code, CodeTypedDict
    from .chatgenerationparams import (
        ChatGenerationParams,
        ChatGenerationParamsDataCollection,
        ChatGenerationParamsImageConfig,
        ChatGenerationParamsImageConfigTypedDict,
        ChatGenerationParamsMaxPrice,
        ChatGenerationParamsMaxPriceTypedDict,
        ChatGenerationParamsPluginAutoRouter,
        ChatGenerationParamsPluginAutoRouterTypedDict,
        ChatGenerationParamsPluginFileParser,
        ChatGenerationParamsPluginFileParserTypedDict,
        ChatGenerationParamsPluginModeration,
        ChatGenerationParamsPluginModerationTypedDict,
        ChatGenerationParamsPluginResponseHealing,
        ChatGenerationParamsPluginResponseHealingTypedDict,
        ChatGenerationParamsPluginUnion,
        ChatGenerationParamsPluginUnionTypedDict,
        ChatGenerationParamsPluginWeb,
        ChatGenerationParamsPluginWebTypedDict,
        ChatGenerationParamsPreferredMaxLatency,
        ChatGenerationParamsPreferredMaxLatencyTypedDict,
        ChatGenerationParamsPreferredMaxLatencyUnion,
        ChatGenerationParamsPreferredMaxLatencyUnionTypedDict,
        ChatGenerationParamsPreferredMinThroughput,
        ChatGenerationParamsPreferredMinThroughputTypedDict,
        ChatGenerationParamsPreferredMinThroughputUnion,
        ChatGenerationParamsPreferredMinThroughputUnionTypedDict,
        ChatGenerationParamsProvider,
        ChatGenerationParamsProviderTypedDict,
        ChatGenerationParamsResponseFormatJSONObject,
        ChatGenerationParamsResponseFormatJSONObjectTypedDict,
        ChatGenerationParamsResponseFormatPython,
        ChatGenerationParamsResponseFormatPythonTypedDict,
        ChatGenerationParamsResponseFormatText,
        ChatGenerationParamsResponseFormatTextTypedDict,
        ChatGenerationParamsResponseFormatUnion,
        ChatGenerationParamsResponseFormatUnionTypedDict,
        ChatGenerationParamsStop,
        ChatGenerationParamsStopTypedDict,
        ChatGenerationParamsTypedDict,
        Debug,
        DebugTypedDict,
        Effort,
        Engine,
        Modality,
        Pdf,
        PdfEngine,
        PdfTypedDict,
        Quantizations,
        Reasoning,
        ReasoningTypedDict,
        Route,
    )
    from .chatgenerationtokenusage import (
        ChatGenerationTokenUsage,
        ChatGenerationTokenUsageTypedDict,
        CompletionTokensDetails,
        CompletionTokensDetailsTypedDict,
        PromptTokensDetails,
        PromptTokensDetailsTypedDict,
    )
    from .chatmessagecontentitem import (
        ChatMessageContentItem,
        ChatMessageContentItemTypedDict,
    )
    from .chatmessagecontentitemaudio import (
        ChatMessageContentItemAudio,
        ChatMessageContentItemAudioInputAudio,
        ChatMessageContentItemAudioInputAudioTypedDict,
        ChatMessageContentItemAudioTypedDict,
    )
    from .chatmessagecontentitemcachecontrol import (
        ChatMessageContentItemCacheControl,
        ChatMessageContentItemCacheControlTypedDict,
        TTL,
    )
    from .chatmessagecontentitemimage import (
        ChatMessageContentItemImage,
        ChatMessageContentItemImageDetail,
        ChatMessageContentItemImageTypedDict,
        ImageURL,
        ImageURLTypedDict,
    )
    from .chatmessagecontentitemtext import (
        ChatMessageContentItemText,
        ChatMessageContentItemTextTypedDict,
    )
    from .chatmessagecontentitemvideo import (
        ChatMessageContentItemVideo,
        ChatMessageContentItemVideoInputVideo,
        ChatMessageContentItemVideoInputVideoTypedDict,
        ChatMessageContentItemVideoTypedDict,
        ChatMessageContentItemVideoVideoURL,
        ChatMessageContentItemVideoVideoURLTypedDict,
        VideoURL1,
        VideoURL1TypedDict,
        VideoURL2,
        VideoURL2TypedDict,
    )
    from .chatmessagetokenlogprob import (
        ChatMessageTokenLogprob,
        ChatMessageTokenLogprobTopLogprob,
        ChatMessageTokenLogprobTopLogprobTypedDict,
        ChatMessageTokenLogprobTypedDict,
    )
    from .chatmessagetokenlogprobs import (
        ChatMessageTokenLogprobs,
        ChatMessageTokenLogprobsTypedDict,
    )
    from .chatmessagetoolcall import (
        ChatMessageToolCall,
        ChatMessageToolCallFunction,
        ChatMessageToolCallFunctionTypedDict,
        ChatMessageToolCallTypedDict,
    )
    from .chatresponse import ChatResponse, ChatResponseTypedDict
    from .chatresponsechoice import ChatResponseChoice, ChatResponseChoiceTypedDict
    from .chatstreamingchoice import ChatStreamingChoice, ChatStreamingChoiceTypedDict
    from .chatstreamingmessagechunk import (
        ChatStreamingMessageChunk,
        ChatStreamingMessageChunkRole,
        ChatStreamingMessageChunkTypedDict,
    )
    from .chatstreamingmessagetoolcall import (
        ChatStreamingMessageToolCall,
        ChatStreamingMessageToolCallFunction,
        ChatStreamingMessageToolCallFunctionTypedDict,
        ChatStreamingMessageToolCallTypedDict,
    )
    from .chatstreamingresponsechunk import (
        ChatStreamingResponseChunk,
        ChatStreamingResponseChunkData,
        ChatStreamingResponseChunkDataTypedDict,
        ChatStreamingResponseChunkError,
        ChatStreamingResponseChunkErrorTypedDict,
        ChatStreamingResponseChunkTypedDict,
    )
    from .chatstreamoptions import ChatStreamOptions, ChatStreamOptionsTypedDict
    from .completionchoice import (
        CompletionChoice,
        CompletionChoiceTypedDict,
        CompletionFinishReason,
    )
    from .completioncreateparams import (
        CompletionCreateParams,
        CompletionCreateParamsResponseFormatJSONObject,
        CompletionCreateParamsResponseFormatJSONObjectTypedDict,
        CompletionCreateParamsResponseFormatPython,
        CompletionCreateParamsResponseFormatPythonTypedDict,
        CompletionCreateParamsResponseFormatText,
        CompletionCreateParamsResponseFormatTextTypedDict,
        CompletionCreateParamsResponseFormatUnion,
        CompletionCreateParamsResponseFormatUnionTypedDict,
        CompletionCreateParamsStop,
        CompletionCreateParamsStopTypedDict,
        CompletionCreateParamsTypedDict,
        Prompt,
        PromptTypedDict,
        StreamOptions,
        StreamOptionsTypedDict,
    )
    from .completionlogprobs import CompletionLogprobs, CompletionLogprobsTypedDict
    from .completionresponse import CompletionResponse, CompletionResponseTypedDict
    from .completionusage import CompletionUsage, CompletionUsageTypedDict
    from .createchargerequest import (
        ChainID,
        CreateChargeRequest,
        CreateChargeRequestTypedDict,
    )
    from .datacollection import DataCollection
    from .defaultparameters import DefaultParameters, DefaultParametersTypedDict
    from .edgenetworktimeoutresponseerrordata import (
        EdgeNetworkTimeoutResponseErrorData,
        EdgeNetworkTimeoutResponseErrorDataTypedDict,
    )
    from .endpointstatus import EndpointStatus
    from .filecitation import FileCitation, FileCitationType, FileCitationTypedDict
    from .filepath import FilePath, FilePathType, FilePathTypedDict
    from .forbiddenresponseerrordata import (
        ForbiddenResponseErrorData,
        ForbiddenResponseErrorDataTypedDict,
    )
    from .imagegenerationstatus import ImageGenerationStatus
    from .inputmodality import InputModality
    from .instructtype import InstructType
    from .internalserverresponseerrordata import (
        InternalServerResponseErrorData,
        InternalServerResponseErrorDataTypedDict,
    )
    from .jsonschemaconfig import JSONSchemaConfig, JSONSchemaConfigTypedDict
    from .listendpointsresponse import (
        Architecture,
        ArchitectureTypedDict,
        ListEndpointsResponse,
        ListEndpointsResponseTypedDict,
        Tokenizer,
    )
    from .message import (
        Message,
        MessageContent,
        MessageContentTypedDict,
        MessageDeveloper,
        MessageDeveloperTypedDict,
        MessageTypedDict,
    )
    from .model import Model, ModelTypedDict
    from .modelarchitecture import (
        ModelArchitecture,
        ModelArchitectureInstructType,
        ModelArchitectureTypedDict,
    )
    from .modelgroup import ModelGroup
    from .modelscountresponse import (
        ModelsCountResponse,
        ModelsCountResponseData,
        ModelsCountResponseDataTypedDict,
        ModelsCountResponseTypedDict,
    )
    from .modelslistresponse import ModelsListResponse, ModelsListResponseTypedDict
    from .namedtoolchoice import (
        NamedToolChoice,
        NamedToolChoiceFunction,
        NamedToolChoiceFunctionTypedDict,
        NamedToolChoiceTypedDict,
    )
    from .notfoundresponseerrordata import (
        NotFoundResponseErrorData,
        NotFoundResponseErrorDataTypedDict,
    )
    from .openairesponsesannotation import (
        OpenAIResponsesAnnotation,
        OpenAIResponsesAnnotationTypedDict,
    )
    from .openairesponsesincludable import OpenAIResponsesIncludable
    from .openairesponsesincompletedetails import (
        OpenAIResponsesIncompleteDetails,
        OpenAIResponsesIncompleteDetailsTypedDict,
        Reason,
    )
    from .openairesponsesinput_union import (
        OpenAIResponsesInputContent1,
        OpenAIResponsesInputContent1TypedDict,
        OpenAIResponsesInputContent2,
        OpenAIResponsesInputContent2TypedDict,
        OpenAIResponsesInputContent3,
        OpenAIResponsesInputContent3TypedDict,
        OpenAIResponsesInputFunctionCall,
        OpenAIResponsesInputFunctionCallOutput,
        OpenAIResponsesInputFunctionCallOutputTypedDict,
        OpenAIResponsesInputFunctionCallTypedDict,
        OpenAIResponsesInputMessage1,
        OpenAIResponsesInputMessage1TypedDict,
        OpenAIResponsesInputMessage2,
        OpenAIResponsesInputMessage2TypedDict,
        OpenAIResponsesInputRoleAssistant,
        OpenAIResponsesInputRoleDeveloper1,
        OpenAIResponsesInputRoleDeveloper2,
        OpenAIResponsesInputRoleSystem1,
        OpenAIResponsesInputRoleSystem2,
        OpenAIResponsesInputRoleUnion1,
        OpenAIResponsesInputRoleUnion1TypedDict,
        OpenAIResponsesInputRoleUnion2,
        OpenAIResponsesInputRoleUnion2TypedDict,
        OpenAIResponsesInputRoleUser1,
        OpenAIResponsesInputRoleUser2,
        OpenAIResponsesInputTypeFunctionCall,
        OpenAIResponsesInputTypeFunctionCallOutput,
        OpenAIResponsesInputTypeMessage1,
        OpenAIResponsesInputTypeMessage2,
        OpenAIResponsesInputUnion,
        OpenAIResponsesInputUnion1,
        OpenAIResponsesInputUnion1TypedDict,
        OpenAIResponsesInputUnionTypedDict,
    )
    from .openairesponsesprompt import (
        OpenAIResponsesPrompt,
        OpenAIResponsesPromptTypedDict,
        Variables,
        VariablesTypedDict,
    )
    from .openairesponsesreasoningconfig import (
        OpenAIResponsesReasoningConfig,
        OpenAIResponsesReasoningConfigTypedDict,
    )
    from .openairesponsesreasoningeffort import OpenAIResponsesReasoningEffort
    from .openairesponsesrefusalcontent import (
        OpenAIResponsesRefusalContent,
        OpenAIResponsesRefusalContentType,
        OpenAIResponsesRefusalContentTypedDict,
    )
    from .openairesponsesresponsestatus import OpenAIResponsesResponseStatus
    from .openairesponsesservicetier import OpenAIResponsesServiceTier
    from .openairesponsestoolchoice_union import (
        OpenAIResponsesToolChoice,
        OpenAIResponsesToolChoiceAuto,
        OpenAIResponsesToolChoiceFunction,
        OpenAIResponsesToolChoiceFunctionTypedDict,
        OpenAIResponsesToolChoiceNone,
        OpenAIResponsesToolChoiceRequired,
        OpenAIResponsesToolChoiceTypeFunction,
        OpenAIResponsesToolChoiceTypeWebSearchPreview,
        OpenAIResponsesToolChoiceTypeWebSearchPreview20250311,
        OpenAIResponsesToolChoiceTypedDict,
        OpenAIResponsesToolChoiceUnion,
        OpenAIResponsesToolChoiceUnionTypedDict,
        Type,
        TypeTypedDict,
    )
    from .openairesponsestruncation import OpenAIResponsesTruncation
    from .openresponseseasyinputmessage import (
        OpenResponsesEasyInputMessage,
        OpenResponsesEasyInputMessageContentInputImage,
        OpenResponsesEasyInputMessageContentInputImageTypedDict,
        OpenResponsesEasyInputMessageContentType,
        OpenResponsesEasyInputMessageContentUnion1,
        OpenResponsesEasyInputMessageContentUnion1TypedDict,
        OpenResponsesEasyInputMessageContentUnion2,
        OpenResponsesEasyInputMessageContentUnion2TypedDict,
        OpenResponsesEasyInputMessageDetail,
        OpenResponsesEasyInputMessageRoleAssistant,
        OpenResponsesEasyInputMessageRoleDeveloper,
        OpenResponsesEasyInputMessageRoleSystem,
        OpenResponsesEasyInputMessageRoleUnion,
        OpenResponsesEasyInputMessageRoleUnionTypedDict,
        OpenResponsesEasyInputMessageRoleUser,
        OpenResponsesEasyInputMessageTypeMessage,
        OpenResponsesEasyInputMessageTypedDict,
    )
    from .openresponseserrorevent import (
        OpenResponsesErrorEvent,
        OpenResponsesErrorEventType,
        OpenResponsesErrorEventTypedDict,
    )
    from .openresponsesfunctioncalloutput import (
        OpenResponsesFunctionCallOutput,
        OpenResponsesFunctionCallOutputType,
        OpenResponsesFunctionCallOutputTypedDict,
    )
    from .openresponsesfunctiontoolcall import (
        OpenResponsesFunctionToolCall,
        OpenResponsesFunctionToolCallType,
        OpenResponsesFunctionToolCallTypedDict,
    )
    from .openresponsesimagegencallcompleted import (
        OpenResponsesImageGenCallCompleted,
        OpenResponsesImageGenCallCompletedType,
        OpenResponsesImageGenCallCompletedTypedDict,
    )
    from .openresponsesimagegencallgenerating import (
        OpenResponsesImageGenCallGenerating,
        OpenResponsesImageGenCallGeneratingType,
        OpenResponsesImageGenCallGeneratingTypedDict,
    )
    from .openresponsesimagegencallinprogress import (
        OpenResponsesImageGenCallInProgress,
        OpenResponsesImageGenCallInProgressType,
        OpenResponsesImageGenCallInProgressTypedDict,
    )
    from .openresponsesimagegencallpartialimage import (
        OpenResponsesImageGenCallPartialImage,
        OpenResponsesImageGenCallPartialImageType,
        OpenResponsesImageGenCallPartialImageTypedDict,
    )
    from .openresponsesinput import (
        OpenResponsesInput,
        OpenResponsesInput1,
        OpenResponsesInput1TypedDict,
        OpenResponsesInputTypedDict,
    )
    from .openresponsesinputmessageitem import (
        OpenResponsesInputMessageItem,
        OpenResponsesInputMessageItemContentInputImage,
        OpenResponsesInputMessageItemContentInputImageTypedDict,
        OpenResponsesInputMessageItemContentType,
        OpenResponsesInputMessageItemContentUnion,
        OpenResponsesInputMessageItemContentUnionTypedDict,
        OpenResponsesInputMessageItemDetail,
        OpenResponsesInputMessageItemRoleDeveloper,
        OpenResponsesInputMessageItemRoleSystem,
        OpenResponsesInputMessageItemRoleUnion,
        OpenResponsesInputMessageItemRoleUnionTypedDict,
        OpenResponsesInputMessageItemRoleUser,
        OpenResponsesInputMessageItemTypeMessage,
        OpenResponsesInputMessageItemTypedDict,
    )
    from .openresponseslogprobs import (
        OpenResponsesLogProbs,
        OpenResponsesLogProbsTypedDict,
    )
    from .openresponsesnonstreamingresponse import (
        Object,
        OpenResponsesNonStreamingResponse,
        OpenResponsesNonStreamingResponseToolFunction,
        OpenResponsesNonStreamingResponseToolFunctionTypedDict,
        OpenResponsesNonStreamingResponseToolUnion,
        OpenResponsesNonStreamingResponseToolUnionTypedDict,
        OpenResponsesNonStreamingResponseType,
        OpenResponsesNonStreamingResponseTypedDict,
    )
    from .openresponsesreasoning import (
        OpenResponsesReasoning,
        OpenResponsesReasoningFormat,
        OpenResponsesReasoningStatusCompleted,
        OpenResponsesReasoningStatusInProgress,
        OpenResponsesReasoningStatusIncomplete,
        OpenResponsesReasoningStatusUnion,
        OpenResponsesReasoningStatusUnionTypedDict,
        OpenResponsesReasoningType,
        OpenResponsesReasoningTypedDict,
    )
    from .openresponsesreasoningconfig import (
        OpenResponsesReasoningConfig,
        OpenResponsesReasoningConfigTypedDict,
    )
    from .openresponsesreasoningdeltaevent import (
        OpenResponsesReasoningDeltaEvent,
        OpenResponsesReasoningDeltaEventType,
        OpenResponsesReasoningDeltaEventTypedDict,
    )
    from .openresponsesreasoningdoneevent import (
        OpenResponsesReasoningDoneEvent,
        OpenResponsesReasoningDoneEventType,
        OpenResponsesReasoningDoneEventTypedDict,
    )
    from .openresponsesreasoningsummarypartaddedevent import (
        OpenResponsesReasoningSummaryPartAddedEvent,
        OpenResponsesReasoningSummaryPartAddedEventType,
        OpenResponsesReasoningSummaryPartAddedEventTypedDict,
    )
    from .openresponsesreasoningsummarytextdeltaevent import (
        OpenResponsesReasoningSummaryTextDeltaEvent,
        OpenResponsesReasoningSummaryTextDeltaEventType,
        OpenResponsesReasoningSummaryTextDeltaEventTypedDict,
    )
    from .openresponsesreasoningsummarytextdoneevent import (
        OpenResponsesReasoningSummaryTextDoneEvent,
        OpenResponsesReasoningSummaryTextDoneEventType,
        OpenResponsesReasoningSummaryTextDoneEventTypedDict,
    )
    from .openresponsesrequest import (
        IDAutoRouter,
        IDFileParser,
        IDModeration,
        IDResponseHealing,
        IDWeb,
        OpenResponsesRequest,
        OpenResponsesRequestIgnore,
        OpenResponsesRequestIgnoreTypedDict,
        OpenResponsesRequestImageConfig,
        OpenResponsesRequestImageConfigTypedDict,
        OpenResponsesRequestMaxPrice,
        OpenResponsesRequestMaxPriceTypedDict,
        OpenResponsesRequestOnly,
        OpenResponsesRequestOnlyTypedDict,
        OpenResponsesRequestOrder,
        OpenResponsesRequestOrderTypedDict,
        OpenResponsesRequestPluginAutoRouter,
        OpenResponsesRequestPluginAutoRouterTypedDict,
        OpenResponsesRequestPluginFileParser,
        OpenResponsesRequestPluginFileParserTypedDict,
        OpenResponsesRequestPluginModeration,
        OpenResponsesRequestPluginModerationTypedDict,
        OpenResponsesRequestPluginResponseHealing,
        OpenResponsesRequestPluginResponseHealingTypedDict,
        OpenResponsesRequestPluginUnion,
        OpenResponsesRequestPluginUnionTypedDict,
        OpenResponsesRequestPluginWeb,
        OpenResponsesRequestPluginWebTypedDict,
        OpenResponsesRequestProvider,
        OpenResponsesRequestProviderTypedDict,
        OpenResponsesRequestSort,
        OpenResponsesRequestSortTypedDict,
        OpenResponsesRequestToolFunction,
        OpenResponsesRequestToolFunctionTypedDict,
        OpenResponsesRequestToolUnion,
        OpenResponsesRequestToolUnionTypedDict,
        OpenResponsesRequestType,
        OpenResponsesRequestTypedDict,
        ServiceTier,
        Truncation,
    )
    from .openresponsesresponsetext import (
        OpenResponsesResponseText,
        OpenResponsesResponseTextTypedDict,
        OpenResponsesResponseTextVerbosity,
    )
    from .openresponsesstreamevent import (
        OpenResponsesStreamEvent,
        OpenResponsesStreamEventResponseCompleted,
        OpenResponsesStreamEventResponseCompletedTypedDict,
        OpenResponsesStreamEventResponseContentPartAdded,
        OpenResponsesStreamEventResponseContentPartAddedTypedDict,
        OpenResponsesStreamEventResponseContentPartDone,
        OpenResponsesStreamEventResponseContentPartDoneTypedDict,
        OpenResponsesStreamEventResponseCreated,
        OpenResponsesStreamEventResponseCreatedTypedDict,
        OpenResponsesStreamEventResponseFailed,
        OpenResponsesStreamEventResponseFailedTypedDict,
        OpenResponsesStreamEventResponseFunctionCallArgumentsDelta,
        OpenResponsesStreamEventResponseFunctionCallArgumentsDeltaTypedDict,
        OpenResponsesStreamEventResponseFunctionCallArgumentsDone,
        OpenResponsesStreamEventResponseFunctionCallArgumentsDoneTypedDict,
        OpenResponsesStreamEventResponseInProgress,
        OpenResponsesStreamEventResponseInProgressTypedDict,
        OpenResponsesStreamEventResponseIncomplete,
        OpenResponsesStreamEventResponseIncompleteTypedDict,
        OpenResponsesStreamEventResponseOutputItemAdded,
        OpenResponsesStreamEventResponseOutputItemAddedTypedDict,
        OpenResponsesStreamEventResponseOutputItemDone,
        OpenResponsesStreamEventResponseOutputItemDoneTypedDict,
        OpenResponsesStreamEventResponseOutputTextAnnotationAdded,
        OpenResponsesStreamEventResponseOutputTextAnnotationAddedTypedDict,
        OpenResponsesStreamEventResponseOutputTextDelta,
        OpenResponsesStreamEventResponseOutputTextDeltaTypedDict,
        OpenResponsesStreamEventResponseOutputTextDone,
        OpenResponsesStreamEventResponseOutputTextDoneTypedDict,
        OpenResponsesStreamEventResponseReasoningSummaryPartDone,
        OpenResponsesStreamEventResponseReasoningSummaryPartDoneTypedDict,
        OpenResponsesStreamEventResponseRefusalDelta,
        OpenResponsesStreamEventResponseRefusalDeltaTypedDict,
        OpenResponsesStreamEventResponseRefusalDone,
        OpenResponsesStreamEventResponseRefusalDoneTypedDict,
        OpenResponsesStreamEventTypedDict,
        Part1,
        Part1TypedDict,
        Part2,
        Part2TypedDict,
        TypeResponseCompleted,
        TypeResponseContentPartAdded,
        TypeResponseContentPartDone,
        TypeResponseCreated,
        TypeResponseFailed,
        TypeResponseFunctionCallArgumentsDelta,
        TypeResponseFunctionCallArgumentsDone,
        TypeResponseInProgress,
        TypeResponseIncomplete,
        TypeResponseOutputItemAdded,
        TypeResponseOutputItemDone,
        TypeResponseOutputTextAnnotationAdded,
        TypeResponseOutputTextDelta,
        TypeResponseOutputTextDone,
        TypeResponseReasoningSummaryPartDone,
        TypeResponseRefusalDelta,
        TypeResponseRefusalDone,
    )
    from .openresponsestoplogprobs import (
        OpenResponsesTopLogprobs,
        OpenResponsesTopLogprobsTypedDict,
    )
    from .openresponsesusage import (
        CostDetails,
        CostDetailsTypedDict,
        InputTokensDetails,
        InputTokensDetailsTypedDict,
        OpenResponsesUsage,
        OpenResponsesUsageTypedDict,
        OutputTokensDetails,
        OutputTokensDetailsTypedDict,
    )
    from .openresponseswebsearch20250826tool import (
        OpenResponsesWebSearch20250826Tool,
        OpenResponsesWebSearch20250826ToolFilters,
        OpenResponsesWebSearch20250826ToolFiltersTypedDict,
        OpenResponsesWebSearch20250826ToolType,
        OpenResponsesWebSearch20250826ToolTypedDict,
    )
    from .openresponseswebsearchpreview20250311tool import (
        OpenResponsesWebSearchPreview20250311Tool,
        OpenResponsesWebSearchPreview20250311ToolType,
        OpenResponsesWebSearchPreview20250311ToolTypedDict,
    )
    from .openresponseswebsearchpreviewtool import (
        OpenResponsesWebSearchPreviewTool,
        OpenResponsesWebSearchPreviewToolType,
        OpenResponsesWebSearchPreviewToolTypedDict,
    )
    from .openresponseswebsearchtool import (
        OpenResponsesWebSearchTool,
        OpenResponsesWebSearchToolFilters,
        OpenResponsesWebSearchToolFiltersTypedDict,
        OpenResponsesWebSearchToolType,
        OpenResponsesWebSearchToolTypedDict,
    )
    from .outputitemimagegenerationcall import (
        OutputItemImageGenerationCall,
        OutputItemImageGenerationCallType,
        OutputItemImageGenerationCallTypedDict,
    )
    from .outputmessage import (
        OutputMessage,
        OutputMessageContent,
        OutputMessageContentTypedDict,
        OutputMessageRole,
        OutputMessageStatusCompleted,
        OutputMessageStatusInProgress,
        OutputMessageStatusIncomplete,
        OutputMessageStatusUnion,
        OutputMessageStatusUnionTypedDict,
        OutputMessageType,
        OutputMessageTypedDict,
    )
    from .outputmodality import OutputModality
    from .parameter import Parameter
    from .payloadtoolargeresponseerrordata import (
        PayloadTooLargeResponseErrorData,
        PayloadTooLargeResponseErrorDataTypedDict,
    )
    from .paymentrequiredresponseerrordata import (
        PaymentRequiredResponseErrorData,
        PaymentRequiredResponseErrorDataTypedDict,
    )
    from .pdfparserengine import PDFParserEngine
    from .pdfparseroptions import PDFParserOptions, PDFParserOptionsTypedDict
    from .percentilelatencycutoffs import (
        PercentileLatencyCutoffs,
        PercentileLatencyCutoffsTypedDict,
    )
    from .percentilestats import PercentileStats, PercentileStatsTypedDict
    from .percentilethroughputcutoffs import (
        PercentileThroughputCutoffs,
        PercentileThroughputCutoffsTypedDict,
    )
    from .perrequestlimits import PerRequestLimits, PerRequestLimitsTypedDict
    from .preferredmaxlatency import PreferredMaxLatency, PreferredMaxLatencyTypedDict
    from .preferredminthroughput import (
        PreferredMinThroughput,
        PreferredMinThroughputTypedDict,
    )
    from .providername import ProviderName
    from .provideroverloadedresponseerrordata import (
        ProviderOverloadedResponseErrorData,
        ProviderOverloadedResponseErrorDataTypedDict,
    )
    from .providerpreferences import (
        ProviderPreferences,
        ProviderPreferencesIgnore,
        ProviderPreferencesIgnoreTypedDict,
        ProviderPreferencesMaxPrice,
        ProviderPreferencesMaxPriceTypedDict,
        ProviderPreferencesOnly,
        ProviderPreferencesOnlyTypedDict,
        ProviderPreferencesOrder,
        ProviderPreferencesOrderTypedDict,
        ProviderPreferencesPartition,
        ProviderPreferencesProviderSort,
        ProviderPreferencesProviderSortConfig,
        ProviderPreferencesProviderSortConfigTypedDict,
        ProviderPreferencesSortUnion,
        ProviderPreferencesSortUnionTypedDict,
        ProviderPreferencesTypedDict,
        ProviderSortConfigEnum,
        ProviderSortConfigUnion,
        ProviderSortConfigUnionTypedDict,
        SortEnum,
    )
    from .providersort import ProviderSort
    from .providersortconfig import (
        Partition,
        ProviderSortConfig,
        ProviderSortConfigTypedDict,
    )
    from .providersortunion import ProviderSortUnion, ProviderSortUnionTypedDict
    from .publicendpoint import (
        Pricing,
        PricingTypedDict,
        PublicEndpoint,
        PublicEndpointQuantization,
        PublicEndpointTypedDict,
    )
    from .publicpricing import PublicPricing, PublicPricingTypedDict
    from .quantization import Quantization
    from .reasoningsummarytext import (
        ReasoningSummaryText,
        ReasoningSummaryTextType,
        ReasoningSummaryTextTypedDict,
    )
    from .reasoningsummaryverbosity import ReasoningSummaryVerbosity
    from .reasoningtextcontent import (
        ReasoningTextContent,
        ReasoningTextContentType,
        ReasoningTextContentTypedDict,
    )
    from .requesttimeoutresponseerrordata import (
        RequestTimeoutResponseErrorData,
        RequestTimeoutResponseErrorDataTypedDict,
    )
    from .responseformatjsonschema import (
        ResponseFormatJSONSchema,
        ResponseFormatJSONSchemaTypedDict,
    )
    from .responseformattextconfig import (
        ResponseFormatTextConfig,
        ResponseFormatTextConfigTypedDict,
    )
    from .responseformattextgrammar import (
        ResponseFormatTextGrammar,
        ResponseFormatTextGrammarTypedDict,
    )
    from .responseinputaudio import (
        ResponseInputAudio,
        ResponseInputAudioFormat,
        ResponseInputAudioInputAudio,
        ResponseInputAudioInputAudioTypedDict,
        ResponseInputAudioType,
        ResponseInputAudioTypedDict,
    )
    from .responseinputfile import (
        ResponseInputFile,
        ResponseInputFileType,
        ResponseInputFileTypedDict,
    )
    from .responseinputimage import (
        ResponseInputImage,
        ResponseInputImageDetail,
        ResponseInputImageType,
        ResponseInputImageTypedDict,
    )
    from .responseinputtext import (
        ResponseInputText,
        ResponseInputTextType,
        ResponseInputTextTypedDict,
    )
    from .responseinputvideo import (
        ResponseInputVideo,
        ResponseInputVideoType,
        ResponseInputVideoTypedDict,
    )
    from .responseoutputtext import (
        Logprob,
        LogprobTypedDict,
        ResponseOutputText,
        ResponseOutputTextTopLogprob,
        ResponseOutputTextTopLogprobTypedDict,
        ResponseOutputTextType,
        ResponseOutputTextTypedDict,
    )
    from .responseserrorfield import (
        CodeEnum,
        ResponsesErrorField,
        ResponsesErrorFieldTypedDict,
    )
    from .responsesformatjsonobject import (
        ResponsesFormatJSONObject,
        ResponsesFormatJSONObjectType,
        ResponsesFormatJSONObjectTypedDict,
    )
    from .responsesformattext import (
        ResponsesFormatText,
        ResponsesFormatTextType,
        ResponsesFormatTextTypedDict,
    )
    from .responsesformattextjsonschemaconfig import (
        ResponsesFormatTextJSONSchemaConfig,
        ResponsesFormatTextJSONSchemaConfigType,
        ResponsesFormatTextJSONSchemaConfigTypedDict,
    )
    from .responsesimagegenerationcall import (
        ResponsesImageGenerationCall,
        ResponsesImageGenerationCallType,
        ResponsesImageGenerationCallTypedDict,
    )
    from .responsesoutputitem import ResponsesOutputItem, ResponsesOutputItemTypedDict
    from .responsesoutputitemfilesearchcall import (
        ResponsesOutputItemFileSearchCall,
        ResponsesOutputItemFileSearchCallType,
        ResponsesOutputItemFileSearchCallTypedDict,
    )
    from .responsesoutputitemfunctioncall import (
        ResponsesOutputItemFunctionCall,
        ResponsesOutputItemFunctionCallStatusCompleted,
        ResponsesOutputItemFunctionCallStatusInProgress,
        ResponsesOutputItemFunctionCallStatusIncomplete,
        ResponsesOutputItemFunctionCallStatusUnion,
        ResponsesOutputItemFunctionCallStatusUnionTypedDict,
        ResponsesOutputItemFunctionCallType,
        ResponsesOutputItemFunctionCallTypedDict,
    )
    from .responsesoutputitemreasoning import (
        ResponsesOutputItemReasoning,
        ResponsesOutputItemReasoningFormat,
        ResponsesOutputItemReasoningStatusCompleted,
        ResponsesOutputItemReasoningStatusInProgress,
        ResponsesOutputItemReasoningStatusIncomplete,
        ResponsesOutputItemReasoningStatusUnion,
        ResponsesOutputItemReasoningStatusUnionTypedDict,
        ResponsesOutputItemReasoningType,
        ResponsesOutputItemReasoningTypedDict,
    )
    from .responsesoutputmessage import (
        ResponsesOutputMessage,
        ResponsesOutputMessageContent,
        ResponsesOutputMessageContentTypedDict,
        ResponsesOutputMessageRole,
        ResponsesOutputMessageStatusCompleted,
        ResponsesOutputMessageStatusInProgress,
        ResponsesOutputMessageStatusIncomplete,
        ResponsesOutputMessageStatusUnion,
        ResponsesOutputMessageStatusUnionTypedDict,
        ResponsesOutputMessageType,
        ResponsesOutputMessageTypedDict,
    )
    from .responsesoutputmodality import ResponsesOutputModality
    from .responsessearchcontextsize import ResponsesSearchContextSize
    from .responseswebsearchcalloutput import (
        ResponsesWebSearchCallOutput,
        ResponsesWebSearchCallOutputType,
        ResponsesWebSearchCallOutputTypedDict,
    )
    from .responseswebsearchuserlocation import (
        ResponsesWebSearchUserLocation,
        ResponsesWebSearchUserLocationType,
        ResponsesWebSearchUserLocationTypedDict,
    )
    from .responsetextconfig import (
        ResponseTextConfig,
        ResponseTextConfigTypedDict,
        ResponseTextConfigVerbosity,
    )
    from .security import Security, SecurityTypedDict
    from .serviceunavailableresponseerrordata import (
        ServiceUnavailableResponseErrorData,
        ServiceUnavailableResponseErrorDataTypedDict,
    )
    from .systemmessage import (
        SystemMessage,
        SystemMessageContent,
        SystemMessageContentTypedDict,
        SystemMessageTypedDict,
    )
    from .toolcallstatus import ToolCallStatus
    from .tooldefinitionjson import (
        ToolDefinitionJSON,
        ToolDefinitionJSONFunction,
        ToolDefinitionJSONFunctionTypedDict,
        ToolDefinitionJSONTypedDict,
    )
    from .toolresponsemessage import (
        ToolResponseMessage,
        ToolResponseMessageContent,
        ToolResponseMessageContentTypedDict,
        ToolResponseMessageTypedDict,
    )
    from .toomanyrequestsresponseerrordata import (
        TooManyRequestsResponseErrorData,
        TooManyRequestsResponseErrorDataTypedDict,
    )
    from .topproviderinfo import TopProviderInfo, TopProviderInfoTypedDict
    from .unauthorizedresponseerrordata import (
        UnauthorizedResponseErrorData,
        UnauthorizedResponseErrorDataTypedDict,
    )
    from .unprocessableentityresponseerrordata import (
        UnprocessableEntityResponseErrorData,
        UnprocessableEntityResponseErrorDataTypedDict,
    )
    from .urlcitation import URLCitation, URLCitationType, URLCitationTypedDict
    from .usermessage import (
        UserMessage,
        UserMessageContent,
        UserMessageContentTypedDict,
        UserMessageTypedDict,
    )
    from .websearchengine import WebSearchEngine
    from .websearchpreviewtooluserlocation import (
        WebSearchPreviewToolUserLocation,
        WebSearchPreviewToolUserLocationType,
        WebSearchPreviewToolUserLocationTypedDict,
    )
    from .websearchstatus import WebSearchStatus

__all__ = [
    "ActivityItem",
    "ActivityItemTypedDict",
    "Architecture",
    "ArchitectureTypedDict",
    "AssistantMessage",
    "AssistantMessageContent",
    "AssistantMessageContentTypedDict",
    "AssistantMessageTypedDict",
    "BadGatewayResponseErrorData",
    "BadGatewayResponseErrorDataTypedDict",
    "BadRequestResponseErrorData",
    "BadRequestResponseErrorDataTypedDict",
    "ChainID",
    "ChatCompletionFinishReason",
    "ChatErrorError",
    "ChatErrorErrorTypedDict",
    "ChatGenerationParams",
    "ChatGenerationParamsDataCollection",
    "ChatGenerationParamsImageConfig",
    "ChatGenerationParamsImageConfigTypedDict",
    "ChatGenerationParamsMaxPrice",
    "ChatGenerationParamsMaxPriceTypedDict",
    "ChatGenerationParamsPluginAutoRouter",
    "ChatGenerationParamsPluginAutoRouterTypedDict",
    "ChatGenerationParamsPluginFileParser",
    "ChatGenerationParamsPluginFileParserTypedDict",
    "ChatGenerationParamsPluginModeration",
    "ChatGenerationParamsPluginModerationTypedDict",
    "ChatGenerationParamsPluginResponseHealing",
    "ChatGenerationParamsPluginResponseHealingTypedDict",
    "ChatGenerationParamsPluginUnion",
    "ChatGenerationParamsPluginUnionTypedDict",
    "ChatGenerationParamsPluginWeb",
    "ChatGenerationParamsPluginWebTypedDict",
    "ChatGenerationParamsPreferredMaxLatency",
    "ChatGenerationParamsPreferredMaxLatencyTypedDict",
    "ChatGenerationParamsPreferredMaxLatencyUnion",
    "ChatGenerationParamsPreferredMaxLatencyUnionTypedDict",
    "ChatGenerationParamsPreferredMinThroughput",
    "ChatGenerationParamsPreferredMinThroughputTypedDict",
    "ChatGenerationParamsPreferredMinThroughputUnion",
    "ChatGenerationParamsPreferredMinThroughputUnionTypedDict",
    "ChatGenerationParamsProvider",
    "ChatGenerationParamsProviderTypedDict",
    "ChatGenerationParamsResponseFormatJSONObject",
    "ChatGenerationParamsResponseFormatJSONObjectTypedDict",
    "ChatGenerationParamsResponseFormatPython",
    "ChatGenerationParamsResponseFormatPythonTypedDict",
    "ChatGenerationParamsResponseFormatText",
    "ChatGenerationParamsResponseFormatTextTypedDict",
    "ChatGenerationParamsResponseFormatUnion",
    "ChatGenerationParamsResponseFormatUnionTypedDict",
    "ChatGenerationParamsStop",
    "ChatGenerationParamsStopTypedDict",
    "ChatGenerationParamsTypedDict",
    "ChatGenerationTokenUsage",
    "ChatGenerationTokenUsageTypedDict",
    "ChatMessageContentItem",
    "ChatMessageContentItemAudio",
    "ChatMessageContentItemAudioInputAudio",
    "ChatMessageContentItemAudioInputAudioTypedDict",
    "ChatMessageContentItemAudioTypedDict",
    "ChatMessageContentItemCacheControl",
    "ChatMessageContentItemCacheControlTypedDict",
    "ChatMessageContentItemImage",
    "ChatMessageContentItemImageDetail",
    "ChatMessageContentItemImageTypedDict",
    "ChatMessageContentItemText",
    "ChatMessageContentItemTextTypedDict",
    "ChatMessageContentItemTypedDict",
    "ChatMessageContentItemVideo",
    "ChatMessageContentItemVideoInputVideo",
    "ChatMessageContentItemVideoInputVideoTypedDict",
    "ChatMessageContentItemVideoTypedDict",
    "ChatMessageContentItemVideoVideoURL",
    "ChatMessageContentItemVideoVideoURLTypedDict",
    "ChatMessageTokenLogprob",
    "ChatMessageTokenLogprobTopLogprob",
    "ChatMessageTokenLogprobTopLogprobTypedDict",
    "ChatMessageTokenLogprobTypedDict",
    "ChatMessageTokenLogprobs",
    "ChatMessageTokenLogprobsTypedDict",
    "ChatMessageToolCall",
    "ChatMessageToolCallFunction",
    "ChatMessageToolCallFunctionTypedDict",
    "ChatMessageToolCallTypedDict",
    "ChatResponse",
    "ChatResponseChoice",
    "ChatResponseChoiceTypedDict",
    "ChatResponseTypedDict",
    "ChatStreamOptions",
    "ChatStreamOptionsTypedDict",
    "ChatStreamingChoice",
    "ChatStreamingChoiceTypedDict",
    "ChatStreamingMessageChunk",
    "ChatStreamingMessageChunkRole",
    "ChatStreamingMessageChunkTypedDict",
    "ChatStreamingMessageToolCall",
    "ChatStreamingMessageToolCallFunction",
    "ChatStreamingMessageToolCallFunctionTypedDict",
    "ChatStreamingMessageToolCallTypedDict",
    "ChatStreamingResponseChunk",
    "ChatStreamingResponseChunkData",
    "ChatStreamingResponseChunkDataTypedDict",
    "ChatStreamingResponseChunkError",
    "ChatStreamingResponseChunkErrorTypedDict",
    "ChatStreamingResponseChunkTypedDict",
    "Code",
    "CodeEnum",
    "CodeTypedDict",
    "CompletionChoice",
    "CompletionChoiceTypedDict",
    "CompletionCreateParams",
    "CompletionCreateParamsResponseFormatJSONObject",
    "CompletionCreateParamsResponseFormatJSONObjectTypedDict",
    "CompletionCreateParamsResponseFormatPython",
    "CompletionCreateParamsResponseFormatPythonTypedDict",
    "CompletionCreateParamsResponseFormatText",
    "CompletionCreateParamsResponseFormatTextTypedDict",
    "CompletionCreateParamsResponseFormatUnion",
    "CompletionCreateParamsResponseFormatUnionTypedDict",
    "CompletionCreateParamsStop",
    "CompletionCreateParamsStopTypedDict",
    "CompletionCreateParamsTypedDict",
    "CompletionFinishReason",
    "CompletionLogprobs",
    "CompletionLogprobsTypedDict",
    "CompletionResponse",
    "CompletionResponseTypedDict",
    "CompletionTokensDetails",
    "CompletionTokensDetailsTypedDict",
    "CompletionUsage",
    "CompletionUsageTypedDict",
    "CostDetails",
    "CostDetailsTypedDict",
    "CreateChargeRequest",
    "CreateChargeRequestTypedDict",
    "DataCollection",
    "Debug",
    "DebugTypedDict",
    "DefaultParameters",
    "DefaultParametersTypedDict",
    "EdgeNetworkTimeoutResponseErrorData",
    "EdgeNetworkTimeoutResponseErrorDataTypedDict",
    "Effort",
    "EndpointStatus",
    "Engine",
    "FileCitation",
    "FileCitationType",
    "FileCitationTypedDict",
    "FilePath",
    "FilePathType",
    "FilePathTypedDict",
    "ForbiddenResponseErrorData",
    "ForbiddenResponseErrorDataTypedDict",
    "IDAutoRouter",
    "IDFileParser",
    "IDModeration",
    "IDResponseHealing",
    "IDWeb",
    "ImageGenerationStatus",
    "ImageURL",
    "ImageURLTypedDict",
    "InputModality",
    "InputTokensDetails",
    "InputTokensDetailsTypedDict",
    "InstructType",
    "InternalServerResponseErrorData",
    "InternalServerResponseErrorDataTypedDict",
    "JSONSchemaConfig",
    "JSONSchemaConfigTypedDict",
    "ListEndpointsResponse",
    "ListEndpointsResponseTypedDict",
    "Logprob",
    "LogprobTypedDict",
    "Message",
    "MessageContent",
    "MessageContentTypedDict",
    "MessageDeveloper",
    "MessageDeveloperTypedDict",
    "MessageTypedDict",
    "Modality",
    "Model",
    "ModelArchitecture",
    "ModelArchitectureInstructType",
    "ModelArchitectureTypedDict",
    "ModelGroup",
    "ModelTypedDict",
    "ModelsCountResponse",
    "ModelsCountResponseData",
    "ModelsCountResponseDataTypedDict",
    "ModelsCountResponseTypedDict",
    "ModelsListResponse",
    "ModelsListResponseTypedDict",
    "NamedToolChoice",
    "NamedToolChoiceFunction",
    "NamedToolChoiceFunctionTypedDict",
    "NamedToolChoiceTypedDict",
    "NotFoundResponseErrorData",
    "NotFoundResponseErrorDataTypedDict",
    "Object",
    "OpenAIResponsesAnnotation",
    "OpenAIResponsesAnnotationTypedDict",
    "OpenAIResponsesIncludable",
    "OpenAIResponsesIncompleteDetails",
    "OpenAIResponsesIncompleteDetailsTypedDict",
    "OpenAIResponsesInputContent1",
    "OpenAIResponsesInputContent1TypedDict",
    "OpenAIResponsesInputContent2",
    "OpenAIResponsesInputContent2TypedDict",
    "OpenAIResponsesInputContent3",
    "OpenAIResponsesInputContent3TypedDict",
    "OpenAIResponsesInputFunctionCall",
    "OpenAIResponsesInputFunctionCallOutput",
    "OpenAIResponsesInputFunctionCallOutputTypedDict",
    "OpenAIResponsesInputFunctionCallTypedDict",
    "OpenAIResponsesInputMessage1",
    "OpenAIResponsesInputMessage1TypedDict",
    "OpenAIResponsesInputMessage2",
    "OpenAIResponsesInputMessage2TypedDict",
    "OpenAIResponsesInputRoleAssistant",
    "OpenAIResponsesInputRoleDeveloper1",
    "OpenAIResponsesInputRoleDeveloper2",
    "OpenAIResponsesInputRoleSystem1",
    "OpenAIResponsesInputRoleSystem2",
    "OpenAIResponsesInputRoleUnion1",
    "OpenAIResponsesInputRoleUnion1TypedDict",
    "OpenAIResponsesInputRoleUnion2",
    "OpenAIResponsesInputRoleUnion2TypedDict",
    "OpenAIResponsesInputRoleUser1",
    "OpenAIResponsesInputRoleUser2",
    "OpenAIResponsesInputTypeFunctionCall",
    "OpenAIResponsesInputTypeFunctionCallOutput",
    "OpenAIResponsesInputTypeMessage1",
    "OpenAIResponsesInputTypeMessage2",
    "OpenAIResponsesInputUnion",
    "OpenAIResponsesInputUnion1",
    "OpenAIResponsesInputUnion1TypedDict",
    "OpenAIResponsesInputUnionTypedDict",
    "OpenAIResponsesPrompt",
    "OpenAIResponsesPromptTypedDict",
    "OpenAIResponsesReasoningConfig",
    "OpenAIResponsesReasoningConfigTypedDict",
    "OpenAIResponsesReasoningEffort",
    "OpenAIResponsesRefusalContent",
    "OpenAIResponsesRefusalContentType",
    "OpenAIResponsesRefusalContentTypedDict",
    "OpenAIResponsesResponseStatus",
    "OpenAIResponsesServiceTier",
    "OpenAIResponsesToolChoice",
    "OpenAIResponsesToolChoiceAuto",
    "OpenAIResponsesToolChoiceFunction",
    "OpenAIResponsesToolChoiceFunctionTypedDict",
    "OpenAIResponsesToolChoiceNone",
    "OpenAIResponsesToolChoiceRequired",
    "OpenAIResponsesToolChoiceTypeFunction",
    "OpenAIResponsesToolChoiceTypeWebSearchPreview",
    "OpenAIResponsesToolChoiceTypeWebSearchPreview20250311",
    "OpenAIResponsesToolChoiceTypedDict",
    "OpenAIResponsesToolChoiceUnion",
    "OpenAIResponsesToolChoiceUnionTypedDict",
    "OpenAIResponsesTruncation",
    "OpenResponsesEasyInputMessage",
    "OpenResponsesEasyInputMessageContentInputImage",
    "OpenResponsesEasyInputMessageContentInputImageTypedDict",
    "OpenResponsesEasyInputMessageContentType",
    "OpenResponsesEasyInputMessageContentUnion1",
    "OpenResponsesEasyInputMessageContentUnion1TypedDict",
    "OpenResponsesEasyInputMessageContentUnion2",
    "OpenResponsesEasyInputMessageContentUnion2TypedDict",
    "OpenResponsesEasyInputMessageDetail",
    "OpenResponsesEasyInputMessageRoleAssistant",
    "OpenResponsesEasyInputMessageRoleDeveloper",
    "OpenResponsesEasyInputMessageRoleSystem",
    "OpenResponsesEasyInputMessageRoleUnion",
    "OpenResponsesEasyInputMessageRoleUnionTypedDict",
    "OpenResponsesEasyInputMessageRoleUser",
    "OpenResponsesEasyInputMessageTypeMessage",
    "OpenResponsesEasyInputMessageTypedDict",
    "OpenResponsesErrorEvent",
    "OpenResponsesErrorEventType",
    "OpenResponsesErrorEventTypedDict",
    "OpenResponsesFunctionCallOutput",
    "OpenResponsesFunctionCallOutputType",
    "OpenResponsesFunctionCallOutputTypedDict",
    "OpenResponsesFunctionToolCall",
    "OpenResponsesFunctionToolCallType",
    "OpenResponsesFunctionToolCallTypedDict",
    "OpenResponsesImageGenCallCompleted",
    "OpenResponsesImageGenCallCompletedType",
    "OpenResponsesImageGenCallCompletedTypedDict",
    "OpenResponsesImageGenCallGenerating",
    "OpenResponsesImageGenCallGeneratingType",
    "OpenResponsesImageGenCallGeneratingTypedDict",
    "OpenResponsesImageGenCallInProgress",
    "OpenResponsesImageGenCallInProgressType",
    "OpenResponsesImageGenCallInProgressTypedDict",
    "OpenResponsesImageGenCallPartialImage",
    "OpenResponsesImageGenCallPartialImageType",
    "OpenResponsesImageGenCallPartialImageTypedDict",
    "OpenResponsesInput",
    "OpenResponsesInput1",
    "OpenResponsesInput1TypedDict",
    "OpenResponsesInputMessageItem",
    "OpenResponsesInputMessageItemContentInputImage",
    "OpenResponsesInputMessageItemContentInputImageTypedDict",
    "OpenResponsesInputMessageItemContentType",
    "OpenResponsesInputMessageItemContentUnion",
    "OpenResponsesInputMessageItemContentUnionTypedDict",
    "OpenResponsesInputMessageItemDetail",
    "OpenResponsesInputMessageItemRoleDeveloper",
    "OpenResponsesInputMessageItemRoleSystem",
    "OpenResponsesInputMessageItemRoleUnion",
    "OpenResponsesInputMessageItemRoleUnionTypedDict",
    "OpenResponsesInputMessageItemRoleUser",
    "OpenResponsesInputMessageItemTypeMessage",
    "OpenResponsesInputMessageItemTypedDict",
    "OpenResponsesInputTypedDict",
    "OpenResponsesLogProbs",
    "OpenResponsesLogProbsTypedDict",
    "OpenResponsesNonStreamingResponse",
    "OpenResponsesNonStreamingResponseToolFunction",
    "OpenResponsesNonStreamingResponseToolFunctionTypedDict",
    "OpenResponsesNonStreamingResponseToolUnion",
    "OpenResponsesNonStreamingResponseToolUnionTypedDict",
    "OpenResponsesNonStreamingResponseType",
    "OpenResponsesNonStreamingResponseTypedDict",
    "OpenResponsesReasoning",
    "OpenResponsesReasoningConfig",
    "OpenResponsesReasoningConfigTypedDict",
    "OpenResponsesReasoningDeltaEvent",
    "OpenResponsesReasoningDeltaEventType",
    "OpenResponsesReasoningDeltaEventTypedDict",
    "OpenResponsesReasoningDoneEvent",
    "OpenResponsesReasoningDoneEventType",
    "OpenResponsesReasoningDoneEventTypedDict",
    "OpenResponsesReasoningFormat",
    "OpenResponsesReasoningStatusCompleted",
    "OpenResponsesReasoningStatusInProgress",
    "OpenResponsesReasoningStatusIncomplete",
    "OpenResponsesReasoningStatusUnion",
    "OpenResponsesReasoningStatusUnionTypedDict",
    "OpenResponsesReasoningSummaryPartAddedEvent",
    "OpenResponsesReasoningSummaryPartAddedEventType",
    "OpenResponsesReasoningSummaryPartAddedEventTypedDict",
    "OpenResponsesReasoningSummaryTextDeltaEvent",
    "OpenResponsesReasoningSummaryTextDeltaEventType",
    "OpenResponsesReasoningSummaryTextDeltaEventTypedDict",
    "OpenResponsesReasoningSummaryTextDoneEvent",
    "OpenResponsesReasoningSummaryTextDoneEventType",
    "OpenResponsesReasoningSummaryTextDoneEventTypedDict",
    "OpenResponsesReasoningType",
    "OpenResponsesReasoningTypedDict",
    "OpenResponsesRequest",
    "OpenResponsesRequestIgnore",
    "OpenResponsesRequestIgnoreTypedDict",
    "OpenResponsesRequestImageConfig",
    "OpenResponsesRequestImageConfigTypedDict",
    "OpenResponsesRequestMaxPrice",
    "OpenResponsesRequestMaxPriceTypedDict",
    "OpenResponsesRequestOnly",
    "OpenResponsesRequestOnlyTypedDict",
    "OpenResponsesRequestOrder",
    "OpenResponsesRequestOrderTypedDict",
    "OpenResponsesRequestPluginAutoRouter",
    "OpenResponsesRequestPluginAutoRouterTypedDict",
    "OpenResponsesRequestPluginFileParser",
    "OpenResponsesRequestPluginFileParserTypedDict",
    "OpenResponsesRequestPluginModeration",
    "OpenResponsesRequestPluginModerationTypedDict",
    "OpenResponsesRequestPluginResponseHealing",
    "OpenResponsesRequestPluginResponseHealingTypedDict",
    "OpenResponsesRequestPluginUnion",
    "OpenResponsesRequestPluginUnionTypedDict",
    "OpenResponsesRequestPluginWeb",
    "OpenResponsesRequestPluginWebTypedDict",
    "OpenResponsesRequestProvider",
    "OpenResponsesRequestProviderTypedDict",
    "OpenResponsesRequestSort",
    "OpenResponsesRequestSortTypedDict",
    "OpenResponsesRequestToolFunction",
    "OpenResponsesRequestToolFunctionTypedDict",
    "OpenResponsesRequestToolUnion",
    "OpenResponsesRequestToolUnionTypedDict",
    "OpenResponsesRequestType",
    "OpenResponsesRequestTypedDict",
    "OpenResponsesResponseText",
    "OpenResponsesResponseTextTypedDict",
    "OpenResponsesResponseTextVerbosity",
    "OpenResponsesStreamEvent",
    "OpenResponsesStreamEventResponseCompleted",
    "OpenResponsesStreamEventResponseCompletedTypedDict",
    "OpenResponsesStreamEventResponseContentPartAdded",
    "OpenResponsesStreamEventResponseContentPartAddedTypedDict",
    "OpenResponsesStreamEventResponseContentPartDone",
    "OpenResponsesStreamEventResponseContentPartDoneTypedDict",
    "OpenResponsesStreamEventResponseCreated",
    "OpenResponsesStreamEventResponseCreatedTypedDict",
    "OpenResponsesStreamEventResponseFailed",
    "OpenResponsesStreamEventResponseFailedTypedDict",
    "OpenResponsesStreamEventResponseFunctionCallArgumentsDelta",
    "OpenResponsesStreamEventResponseFunctionCallArgumentsDeltaTypedDict",
    "OpenResponsesStreamEventResponseFunctionCallArgumentsDone",
    "OpenResponsesStreamEventResponseFunctionCallArgumentsDoneTypedDict",
    "OpenResponsesStreamEventResponseInProgress",
    "OpenResponsesStreamEventResponseInProgressTypedDict",
    "OpenResponsesStreamEventResponseIncomplete",
    "OpenResponsesStreamEventResponseIncompleteTypedDict",
    "OpenResponsesStreamEventResponseOutputItemAdded",
    "OpenResponsesStreamEventResponseOutputItemAddedTypedDict",
    "OpenResponsesStreamEventResponseOutputItemDone",
    "OpenResponsesStreamEventResponseOutputItemDoneTypedDict",
    "OpenResponsesStreamEventResponseOutputTextAnnotationAdded",
    "OpenResponsesStreamEventResponseOutputTextAnnotationAddedTypedDict",
    "OpenResponsesStreamEventResponseOutputTextDelta",
    "OpenResponsesStreamEventResponseOutputTextDeltaTypedDict",
    "OpenResponsesStreamEventResponseOutputTextDone",
    "OpenResponsesStreamEventResponseOutputTextDoneTypedDict",
    "OpenResponsesStreamEventResponseReasoningSummaryPartDone",
    "OpenResponsesStreamEventResponseReasoningSummaryPartDoneTypedDict",
    "OpenResponsesStreamEventResponseRefusalDelta",
    "OpenResponsesStreamEventResponseRefusalDeltaTypedDict",
    "OpenResponsesStreamEventResponseRefusalDone",
    "OpenResponsesStreamEventResponseRefusalDoneTypedDict",
    "OpenResponsesStreamEventTypedDict",
    "OpenResponsesTopLogprobs",
    "OpenResponsesTopLogprobsTypedDict",
    "OpenResponsesUsage",
    "OpenResponsesUsageTypedDict",
    "OpenResponsesWebSearch20250826Tool",
    "OpenResponsesWebSearch20250826ToolFilters",
    "OpenResponsesWebSearch20250826ToolFiltersTypedDict",
    "OpenResponsesWebSearch20250826ToolType",
    "OpenResponsesWebSearch20250826ToolTypedDict",
    "OpenResponsesWebSearchPreview20250311Tool",
    "OpenResponsesWebSearchPreview20250311ToolType",
    "OpenResponsesWebSearchPreview20250311ToolTypedDict",
    "OpenResponsesWebSearchPreviewTool",
    "OpenResponsesWebSearchPreviewToolType",
    "OpenResponsesWebSearchPreviewToolTypedDict",
    "OpenResponsesWebSearchTool",
    "OpenResponsesWebSearchToolFilters",
    "OpenResponsesWebSearchToolFiltersTypedDict",
    "OpenResponsesWebSearchToolType",
    "OpenResponsesWebSearchToolTypedDict",
    "OutputItemImageGenerationCall",
    "OutputItemImageGenerationCallType",
    "OutputItemImageGenerationCallTypedDict",
    "OutputMessage",
    "OutputMessageContent",
    "OutputMessageContentTypedDict",
    "OutputMessageRole",
    "OutputMessageStatusCompleted",
    "OutputMessageStatusInProgress",
    "OutputMessageStatusIncomplete",
    "OutputMessageStatusUnion",
    "OutputMessageStatusUnionTypedDict",
    "OutputMessageType",
    "OutputMessageTypedDict",
    "OutputModality",
    "OutputTokensDetails",
    "OutputTokensDetailsTypedDict",
    "PDFParserEngine",
    "PDFParserOptions",
    "PDFParserOptionsTypedDict",
    "Parameter",
    "Part1",
    "Part1TypedDict",
    "Part2",
    "Part2TypedDict",
    "Partition",
    "PayloadTooLargeResponseErrorData",
    "PayloadTooLargeResponseErrorDataTypedDict",
    "PaymentRequiredResponseErrorData",
    "PaymentRequiredResponseErrorDataTypedDict",
    "Pdf",
    "PdfEngine",
    "PdfTypedDict",
    "PerRequestLimits",
    "PerRequestLimitsTypedDict",
    "PercentileLatencyCutoffs",
    "PercentileLatencyCutoffsTypedDict",
    "PercentileStats",
    "PercentileStatsTypedDict",
    "PercentileThroughputCutoffs",
    "PercentileThroughputCutoffsTypedDict",
    "PreferredMaxLatency",
    "PreferredMaxLatencyTypedDict",
    "PreferredMinThroughput",
    "PreferredMinThroughputTypedDict",
    "Pricing",
    "PricingTypedDict",
    "Prompt",
    "PromptTokensDetails",
    "PromptTokensDetailsTypedDict",
    "PromptTypedDict",
    "ProviderName",
    "ProviderOverloadedResponseErrorData",
    "ProviderOverloadedResponseErrorDataTypedDict",
    "ProviderPreferences",
    "ProviderPreferencesIgnore",
    "ProviderPreferencesIgnoreTypedDict",
    "ProviderPreferencesMaxPrice",
    "ProviderPreferencesMaxPriceTypedDict",
    "ProviderPreferencesOnly",
    "ProviderPreferencesOnlyTypedDict",
    "ProviderPreferencesOrder",
    "ProviderPreferencesOrderTypedDict",
    "ProviderPreferencesPartition",
    "ProviderPreferencesProviderSort",
    "ProviderPreferencesProviderSortConfig",
    "ProviderPreferencesProviderSortConfigTypedDict",
    "ProviderPreferencesSortUnion",
    "ProviderPreferencesSortUnionTypedDict",
    "ProviderPreferencesTypedDict",
    "ProviderSort",
    "ProviderSortConfig",
    "ProviderSortConfigEnum",
    "ProviderSortConfigTypedDict",
    "ProviderSortConfigUnion",
    "ProviderSortConfigUnionTypedDict",
    "ProviderSortUnion",
    "ProviderSortUnionTypedDict",
    "PublicEndpoint",
    "PublicEndpointQuantization",
    "PublicEndpointTypedDict",
    "PublicPricing",
    "PublicPricingTypedDict",
    "Quantization",
    "Quantizations",
    "Reason",
    "Reasoning",
    "ReasoningSummaryText",
    "ReasoningSummaryTextType",
    "ReasoningSummaryTextTypedDict",
    "ReasoningSummaryVerbosity",
    "ReasoningTextContent",
    "ReasoningTextContentType",
    "ReasoningTextContentTypedDict",
    "ReasoningTypedDict",
    "RequestTimeoutResponseErrorData",
    "RequestTimeoutResponseErrorDataTypedDict",
    "ResponseFormatJSONSchema",
    "ResponseFormatJSONSchemaTypedDict",
    "ResponseFormatTextConfig",
    "ResponseFormatTextConfigTypedDict",
    "ResponseFormatTextGrammar",
    "ResponseFormatTextGrammarTypedDict",
    "ResponseInputAudio",
    "ResponseInputAudioFormat",
    "ResponseInputAudioInputAudio",
    "ResponseInputAudioInputAudioTypedDict",
    "ResponseInputAudioType",
    "ResponseInputAudioTypedDict",
    "ResponseInputFile",
    "ResponseInputFileType",
    "ResponseInputFileTypedDict",
    "ResponseInputImage",
    "ResponseInputImageDetail",
    "ResponseInputImageType",
    "ResponseInputImageTypedDict",
    "ResponseInputText",
    "ResponseInputTextType",
    "ResponseInputTextTypedDict",
    "ResponseInputVideo",
    "ResponseInputVideoType",
    "ResponseInputVideoTypedDict",
    "ResponseOutputText",
    "ResponseOutputTextTopLogprob",
    "ResponseOutputTextTopLogprobTypedDict",
    "ResponseOutputTextType",
    "ResponseOutputTextTypedDict",
    "ResponseTextConfig",
    "ResponseTextConfigTypedDict",
    "ResponseTextConfigVerbosity",
    "ResponsesErrorField",
    "ResponsesErrorFieldTypedDict",
    "ResponsesFormatJSONObject",
    "ResponsesFormatJSONObjectType",
    "ResponsesFormatJSONObjectTypedDict",
    "ResponsesFormatText",
    "ResponsesFormatTextJSONSchemaConfig",
    "ResponsesFormatTextJSONSchemaConfigType",
    "ResponsesFormatTextJSONSchemaConfigTypedDict",
    "ResponsesFormatTextType",
    "ResponsesFormatTextTypedDict",
    "ResponsesImageGenerationCall",
    "ResponsesImageGenerationCallType",
    "ResponsesImageGenerationCallTypedDict",
    "ResponsesOutputItem",
    "ResponsesOutputItemFileSearchCall",
    "ResponsesOutputItemFileSearchCallType",
    "ResponsesOutputItemFileSearchCallTypedDict",
    "ResponsesOutputItemFunctionCall",
    "ResponsesOutputItemFunctionCallStatusCompleted",
    "ResponsesOutputItemFunctionCallStatusInProgress",
    "ResponsesOutputItemFunctionCallStatusIncomplete",
    "ResponsesOutputItemFunctionCallStatusUnion",
    "ResponsesOutputItemFunctionCallStatusUnionTypedDict",
    "ResponsesOutputItemFunctionCallType",
    "ResponsesOutputItemFunctionCallTypedDict",
    "ResponsesOutputItemReasoning",
    "ResponsesOutputItemReasoningFormat",
    "ResponsesOutputItemReasoningStatusCompleted",
    "ResponsesOutputItemReasoningStatusInProgress",
    "ResponsesOutputItemReasoningStatusIncomplete",
    "ResponsesOutputItemReasoningStatusUnion",
    "ResponsesOutputItemReasoningStatusUnionTypedDict",
    "ResponsesOutputItemReasoningType",
    "ResponsesOutputItemReasoningTypedDict",
    "ResponsesOutputItemTypedDict",
    "ResponsesOutputMessage",
    "ResponsesOutputMessageContent",
    "ResponsesOutputMessageContentTypedDict",
    "ResponsesOutputMessageRole",
    "ResponsesOutputMessageStatusCompleted",
    "ResponsesOutputMessageStatusInProgress",
    "ResponsesOutputMessageStatusIncomplete",
    "ResponsesOutputMessageStatusUnion",
    "ResponsesOutputMessageStatusUnionTypedDict",
    "ResponsesOutputMessageType",
    "ResponsesOutputMessageTypedDict",
    "ResponsesOutputModality",
    "ResponsesSearchContextSize",
    "ResponsesWebSearchCallOutput",
    "ResponsesWebSearchCallOutputType",
    "ResponsesWebSearchCallOutputTypedDict",
    "ResponsesWebSearchUserLocation",
    "ResponsesWebSearchUserLocationType",
    "ResponsesWebSearchUserLocationTypedDict",
    "Route",
    "Schema0",
    "Schema0Enum",
    "Schema0TypedDict",
    "Schema3",
    "Schema3ReasoningEncrypted",
    "Schema3ReasoningEncryptedTypedDict",
    "Schema3ReasoningSummary",
    "Schema3ReasoningSummaryTypedDict",
    "Schema3ReasoningText",
    "Schema3ReasoningTextTypedDict",
    "Schema3TypedDict",
    "Schema5",
    "Security",
    "SecurityTypedDict",
    "ServiceTier",
    "ServiceUnavailableResponseErrorData",
    "ServiceUnavailableResponseErrorDataTypedDict",
    "SortEnum",
    "StreamOptions",
    "StreamOptionsTypedDict",
    "SystemMessage",
    "SystemMessageContent",
    "SystemMessageContentTypedDict",
    "SystemMessageTypedDict",
    "TTL",
    "Tokenizer",
    "TooManyRequestsResponseErrorData",
    "TooManyRequestsResponseErrorDataTypedDict",
    "ToolCallStatus",
    "ToolDefinitionJSON",
    "ToolDefinitionJSONFunction",
    "ToolDefinitionJSONFunctionTypedDict",
    "ToolDefinitionJSONTypedDict",
    "ToolResponseMessage",
    "ToolResponseMessageContent",
    "ToolResponseMessageContentTypedDict",
    "ToolResponseMessageTypedDict",
    "TopProviderInfo",
    "TopProviderInfoTypedDict",
    "Truncation",
    "Type",
    "TypeResponseCompleted",
    "TypeResponseContentPartAdded",
    "TypeResponseContentPartDone",
    "TypeResponseCreated",
    "TypeResponseFailed",
    "TypeResponseFunctionCallArgumentsDelta",
    "TypeResponseFunctionCallArgumentsDone",
    "TypeResponseInProgress",
    "TypeResponseIncomplete",
    "TypeResponseOutputItemAdded",
    "TypeResponseOutputItemDone",
    "TypeResponseOutputTextAnnotationAdded",
    "TypeResponseOutputTextDelta",
    "TypeResponseOutputTextDone",
    "TypeResponseReasoningSummaryPartDone",
    "TypeResponseRefusalDelta",
    "TypeResponseRefusalDone",
    "TypeTypedDict",
    "URLCitation",
    "URLCitationType",
    "URLCitationTypedDict",
    "UnauthorizedResponseErrorData",
    "UnauthorizedResponseErrorDataTypedDict",
    "UnprocessableEntityResponseErrorData",
    "UnprocessableEntityResponseErrorDataTypedDict",
    "UserMessage",
    "UserMessageContent",
    "UserMessageContentTypedDict",
    "UserMessageTypedDict",
    "Variables",
    "VariablesTypedDict",
    "VideoURL1",
    "VideoURL1TypedDict",
    "VideoURL2",
    "VideoURL2TypedDict",
    "WebSearchEngine",
    "WebSearchPreviewToolUserLocation",
    "WebSearchPreviewToolUserLocationType",
    "WebSearchPreviewToolUserLocationTypedDict",
    "WebSearchStatus",
]

_dynamic_imports: dict[str, str] = {
    "Schema0": "._schema0",
    "Schema0Enum": "._schema0",
    "Schema0TypedDict": "._schema0",
    "Schema3": "._schema3",
    "Schema3ReasoningEncrypted": "._schema3",
    "Schema3ReasoningEncryptedTypedDict": "._schema3",
    "Schema3ReasoningSummary": "._schema3",
    "Schema3ReasoningSummaryTypedDict": "._schema3",
    "Schema3ReasoningText": "._schema3",
    "Schema3ReasoningTextTypedDict": "._schema3",
    "Schema3TypedDict": "._schema3",
    "Schema5": "._schema3",
    "ActivityItem": ".activityitem",
    "ActivityItemTypedDict": ".activityitem",
    "AssistantMessage": ".assistantmessage",
    "AssistantMessageContent": ".assistantmessage",
    "AssistantMessageContentTypedDict": ".assistantmessage",
    "AssistantMessageTypedDict": ".assistantmessage",
    "BadGatewayResponseErrorData": ".badgatewayresponseerrordata",
    "BadGatewayResponseErrorDataTypedDict": ".badgatewayresponseerrordata",
    "BadRequestResponseErrorData": ".badrequestresponseerrordata",
    "BadRequestResponseErrorDataTypedDict": ".badrequestresponseerrordata",
    "ChatCompletionFinishReason": ".chatcompletionfinishreason",
    "ChatErrorError": ".chaterror",
    "ChatErrorErrorTypedDict": ".chaterror",
    "Code": ".chaterror",
    "CodeTypedDict": ".chaterror",
    "ChatGenerationParams": ".chatgenerationparams",
    "ChatGenerationParamsDataCollection": ".chatgenerationparams",
    "ChatGenerationParamsImageConfig": ".chatgenerationparams",
    "ChatGenerationParamsImageConfigTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsMaxPrice": ".chatgenerationparams",
    "ChatGenerationParamsMaxPriceTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsPluginAutoRouter": ".chatgenerationparams",
    "ChatGenerationParamsPluginAutoRouterTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsPluginFileParser": ".chatgenerationparams",
    "ChatGenerationParamsPluginFileParserTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsPluginModeration": ".chatgenerationparams",
    "ChatGenerationParamsPluginModerationTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsPluginResponseHealing": ".chatgenerationparams",
    "ChatGenerationParamsPluginResponseHealingTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsPluginUnion": ".chatgenerationparams",
    "ChatGenerationParamsPluginUnionTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsPluginWeb": ".chatgenerationparams",
    "ChatGenerationParamsPluginWebTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsPreferredMaxLatency": ".chatgenerationparams",
    "ChatGenerationParamsPreferredMaxLatencyTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsPreferredMaxLatencyUnion": ".chatgenerationparams",
    "ChatGenerationParamsPreferredMaxLatencyUnionTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsPreferredMinThroughput": ".chatgenerationparams",
    "ChatGenerationParamsPreferredMinThroughputTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsPreferredMinThroughputUnion": ".chatgenerationparams",
    "ChatGenerationParamsPreferredMinThroughputUnionTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsProvider": ".chatgenerationparams",
    "ChatGenerationParamsProviderTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsResponseFormatJSONObject": ".chatgenerationparams",
    "ChatGenerationParamsResponseFormatJSONObjectTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsResponseFormatPython": ".chatgenerationparams",
    "ChatGenerationParamsResponseFormatPythonTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsResponseFormatText": ".chatgenerationparams",
    "ChatGenerationParamsResponseFormatTextTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsResponseFormatUnion": ".chatgenerationparams",
    "ChatGenerationParamsResponseFormatUnionTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsStop": ".chatgenerationparams",
    "ChatGenerationParamsStopTypedDict": ".chatgenerationparams",
    "ChatGenerationParamsTypedDict": ".chatgenerationparams",
    "Debug": ".chatgenerationparams",
    "DebugTypedDict": ".chatgenerationparams",
    "Effort": ".chatgenerationparams",
    "Engine": ".chatgenerationparams",
    "Modality": ".chatgenerationparams",
    "Pdf": ".chatgenerationparams",
    "PdfEngine": ".chatgenerationparams",
    "PdfTypedDict": ".chatgenerationparams",
    "Quantizations": ".chatgenerationparams",
    "Reasoning": ".chatgenerationparams",
    "ReasoningTypedDict": ".chatgenerationparams",
    "Route": ".chatgenerationparams",
    "ChatGenerationTokenUsage": ".chatgenerationtokenusage",
    "ChatGenerationTokenUsageTypedDict": ".chatgenerationtokenusage",
    "CompletionTokensDetails": ".chatgenerationtokenusage",
    "CompletionTokensDetailsTypedDict": ".chatgenerationtokenusage",
    "PromptTokensDetails": ".chatgenerationtokenusage",
    "PromptTokensDetailsTypedDict": ".chatgenerationtokenusage",
    "ChatMessageContentItem": ".chatmessagecontentitem",
    "ChatMessageContentItemTypedDict": ".chatmessagecontentitem",
    "ChatMessageContentItemAudio": ".chatmessagecontentitemaudio",
    "ChatMessageContentItemAudioInputAudio": ".chatmessagecontentitemaudio",
    "ChatMessageContentItemAudioInputAudioTypedDict": ".chatmessagecontentitemaudio",
    "ChatMessageContentItemAudioTypedDict": ".chatmessagecontentitemaudio",
    "ChatMessageContentItemCacheControl": ".chatmessagecontentitemcachecontrol",
    "ChatMessageContentItemCacheControlTypedDict": ".chatmessagecontentitemcachecontrol",
    "TTL": ".chatmessagecontentitemcachecontrol",
    "ChatMessageContentItemImage": ".chatmessagecontentitemimage",
    "ChatMessageContentItemImageDetail": ".chatmessagecontentitemimage",
    "ChatMessageContentItemImageTypedDict": ".chatmessagecontentitemimage",
    "ImageURL": ".chatmessagecontentitemimage",
    "ImageURLTypedDict": ".chatmessagecontentitemimage",
    "ChatMessageContentItemText": ".chatmessagecontentitemtext",
    "ChatMessageContentItemTextTypedDict": ".chatmessagecontentitemtext",
    "ChatMessageContentItemVideo": ".chatmessagecontentitemvideo",
    "ChatMessageContentItemVideoInputVideo": ".chatmessagecontentitemvideo",
    "ChatMessageContentItemVideoInputVideoTypedDict": ".chatmessagecontentitemvideo",
    "ChatMessageContentItemVideoTypedDict": ".chatmessagecontentitemvideo",
    "ChatMessageContentItemVideoVideoURL": ".chatmessagecontentitemvideo",
    "ChatMessageContentItemVideoVideoURLTypedDict": ".chatmessagecontentitemvideo",
    "VideoURL1": ".chatmessagecontentitemvideo",
    "VideoURL1TypedDict": ".chatmessagecontentitemvideo",
    "VideoURL2": ".chatmessagecontentitemvideo",
    "VideoURL2TypedDict": ".chatmessagecontentitemvideo",
    "ChatMessageTokenLogprob": ".chatmessagetokenlogprob",
    "ChatMessageTokenLogprobTopLogprob": ".chatmessagetokenlogprob",
    "ChatMessageTokenLogprobTopLogprobTypedDict": ".chatmessagetokenlogprob",
    "ChatMessageTokenLogprobTypedDict": ".chatmessagetokenlogprob",
    "ChatMessageTokenLogprobs": ".chatmessagetokenlogprobs",
    "ChatMessageTokenLogprobsTypedDict": ".chatmessagetokenlogprobs",
    "ChatMessageToolCall": ".chatmessagetoolcall",
    "ChatMessageToolCallFunction": ".chatmessagetoolcall",
    "ChatMessageToolCallFunctionTypedDict": ".chatmessagetoolcall",
    "ChatMessageToolCallTypedDict": ".chatmessagetoolcall",
    "ChatResponse": ".chatresponse",
    "ChatResponseTypedDict": ".chatresponse",
    "ChatResponseChoice": ".chatresponsechoice",
    "ChatResponseChoiceTypedDict": ".chatresponsechoice",
    "ChatStreamingChoice": ".chatstreamingchoice",
    "ChatStreamingChoiceTypedDict": ".chatstreamingchoice",
    "ChatStreamingMessageChunk": ".chatstreamingmessagechunk",
    "ChatStreamingMessageChunkRole": ".chatstreamingmessagechunk",
    "ChatStreamingMessageChunkTypedDict": ".chatstreamingmessagechunk",
    "ChatStreamingMessageToolCall": ".chatstreamingmessagetoolcall",
    "ChatStreamingMessageToolCallFunction": ".chatstreamingmessagetoolcall",
    "ChatStreamingMessageToolCallFunctionTypedDict": ".chatstreamingmessagetoolcall",
    "ChatStreamingMessageToolCallTypedDict": ".chatstreamingmessagetoolcall",
    "ChatStreamingResponseChunk": ".chatstreamingresponsechunk",
    "ChatStreamingResponseChunkData": ".chatstreamingresponsechunk",
    "ChatStreamingResponseChunkDataTypedDict": ".chatstreamingresponsechunk",
    "ChatStreamingResponseChunkError": ".chatstreamingresponsechunk",
    "ChatStreamingResponseChunkErrorTypedDict": ".chatstreamingresponsechunk",
    "ChatStreamingResponseChunkTypedDict": ".chatstreamingresponsechunk",
    "ChatStreamOptions": ".chatstreamoptions",
    "ChatStreamOptionsTypedDict": ".chatstreamoptions",
    "CompletionChoice": ".completionchoice",
    "CompletionChoiceTypedDict": ".completionchoice",
    "CompletionFinishReason": ".completionchoice",
    "CompletionCreateParams": ".completioncreateparams",
    "CompletionCreateParamsResponseFormatJSONObject": ".completioncreateparams",
    "CompletionCreateParamsResponseFormatJSONObjectTypedDict": ".completioncreateparams",
    "CompletionCreateParamsResponseFormatPython": ".completioncreateparams",
    "CompletionCreateParamsResponseFormatPythonTypedDict": ".completioncreateparams",
    "CompletionCreateParamsResponseFormatText": ".completioncreateparams",
    "CompletionCreateParamsResponseFormatTextTypedDict": ".completioncreateparams",
    "CompletionCreateParamsResponseFormatUnion": ".completioncreateparams",
    "CompletionCreateParamsResponseFormatUnionTypedDict": ".completioncreateparams",
    "CompletionCreateParamsStop": ".completioncreateparams",
    "CompletionCreateParamsStopTypedDict": ".completioncreateparams",
    "CompletionCreateParamsTypedDict": ".completioncreateparams",
    "Prompt": ".completioncreateparams",
    "PromptTypedDict": ".completioncreateparams",
    "StreamOptions": ".completioncreateparams",
    "StreamOptionsTypedDict": ".completioncreateparams",
    "CompletionLogprobs": ".completionlogprobs",
    "CompletionLogprobsTypedDict": ".completionlogprobs",
    "CompletionResponse": ".completionresponse",
    "CompletionResponseTypedDict": ".completionresponse",
    "CompletionUsage": ".completionusage",
    "CompletionUsageTypedDict": ".completionusage",
    "ChainID": ".createchargerequest",
    "CreateChargeRequest": ".createchargerequest",
    "CreateChargeRequestTypedDict": ".createchargerequest",
    "DataCollection": ".datacollection",
    "DefaultParameters": ".defaultparameters",
    "DefaultParametersTypedDict": ".defaultparameters",
    "EdgeNetworkTimeoutResponseErrorData": ".edgenetworktimeoutresponseerrordata",
    "EdgeNetworkTimeoutResponseErrorDataTypedDict": ".edgenetworktimeoutresponseerrordata",
    "EndpointStatus": ".endpointstatus",
    "FileCitation": ".filecitation",
    "FileCitationType": ".filecitation",
    "FileCitationTypedDict": ".filecitation",
    "FilePath": ".filepath",
    "FilePathType": ".filepath",
    "FilePathTypedDict": ".filepath",
    "ForbiddenResponseErrorData": ".forbiddenresponseerrordata",
    "ForbiddenResponseErrorDataTypedDict": ".forbiddenresponseerrordata",
    "ImageGenerationStatus": ".imagegenerationstatus",
    "InputModality": ".inputmodality",
    "InstructType": ".instructtype",
    "InternalServerResponseErrorData": ".internalserverresponseerrordata",
    "InternalServerResponseErrorDataTypedDict": ".internalserverresponseerrordata",
    "JSONSchemaConfig": ".jsonschemaconfig",
    "JSONSchemaConfigTypedDict": ".jsonschemaconfig",
    "Architecture": ".listendpointsresponse",
    "ArchitectureTypedDict": ".listendpointsresponse",
    "ListEndpointsResponse": ".listendpointsresponse",
    "ListEndpointsResponseTypedDict": ".listendpointsresponse",
    "Tokenizer": ".listendpointsresponse",
    "Message": ".message",
    "MessageContent": ".message",
    "MessageContentTypedDict": ".message",
    "MessageDeveloper": ".message",
    "MessageDeveloperTypedDict": ".message",
    "MessageTypedDict": ".message",
    "Model": ".model",
    "ModelTypedDict": ".model",
    "ModelArchitecture": ".modelarchitecture",
    "ModelArchitectureInstructType": ".modelarchitecture",
    "ModelArchitectureTypedDict": ".modelarchitecture",
    "ModelGroup": ".modelgroup",
    "ModelsCountResponse": ".modelscountresponse",
    "ModelsCountResponseData": ".modelscountresponse",
    "ModelsCountResponseDataTypedDict": ".modelscountresponse",
    "ModelsCountResponseTypedDict": ".modelscountresponse",
    "ModelsListResponse": ".modelslistresponse",
    "ModelsListResponseTypedDict": ".modelslistresponse",
    "NamedToolChoice": ".namedtoolchoice",
    "NamedToolChoiceFunction": ".namedtoolchoice",
    "NamedToolChoiceFunctionTypedDict": ".namedtoolchoice",
    "NamedToolChoiceTypedDict": ".namedtoolchoice",
    "NotFoundResponseErrorData": ".notfoundresponseerrordata",
    "NotFoundResponseErrorDataTypedDict": ".notfoundresponseerrordata",
    "OpenAIResponsesAnnotation": ".openairesponsesannotation",
    "OpenAIResponsesAnnotationTypedDict": ".openairesponsesannotation",
    "OpenAIResponsesIncludable": ".openairesponsesincludable",
    "OpenAIResponsesIncompleteDetails": ".openairesponsesincompletedetails",
    "OpenAIResponsesIncompleteDetailsTypedDict": ".openairesponsesincompletedetails",
    "Reason": ".openairesponsesincompletedetails",
    "OpenAIResponsesInputContent1": ".openairesponsesinput_union",
    "OpenAIResponsesInputContent1TypedDict": ".openairesponsesinput_union",
    "OpenAIResponsesInputContent2": ".openairesponsesinput_union",
    "OpenAIResponsesInputContent2TypedDict": ".openairesponsesinput_union",
    "OpenAIResponsesInputContent3": ".openairesponsesinput_union",
    "OpenAIResponsesInputContent3TypedDict": ".openairesponsesinput_union",
    "OpenAIResponsesInputFunctionCall": ".openairesponsesinput_union",
    "OpenAIResponsesInputFunctionCallOutput": ".openairesponsesinput_union",
    "OpenAIResponsesInputFunctionCallOutputTypedDict": ".openairesponsesinput_union",
    "OpenAIResponsesInputFunctionCallTypedDict": ".openairesponsesinput_union",
    "OpenAIResponsesInputMessage1": ".openairesponsesinput_union",
    "OpenAIResponsesInputMessage1TypedDict": ".openairesponsesinput_union",
    "OpenAIResponsesInputMessage2": ".openairesponsesinput_union",
    "OpenAIResponsesInputMessage2TypedDict": ".openairesponsesinput_union",
    "OpenAIResponsesInputRoleAssistant": ".openairesponsesinput_union",
    "OpenAIResponsesInputRoleDeveloper1": ".openairesponsesinput_union",
    "OpenAIResponsesInputRoleDeveloper2": ".openairesponsesinput_union",
    "OpenAIResponsesInputRoleSystem1": ".openairesponsesinput_union",
    "OpenAIResponsesInputRoleSystem2": ".openairesponsesinput_union",
    "OpenAIResponsesInputRoleUnion1": ".openairesponsesinput_union",
    "OpenAIResponsesInputRoleUnion1TypedDict": ".openairesponsesinput_union",
    "OpenAIResponsesInputRoleUnion2": ".openairesponsesinput_union",
    "OpenAIResponsesInputRoleUnion2TypedDict": ".openairesponsesinput_union",
    "OpenAIResponsesInputRoleUser1": ".openairesponsesinput_union",
    "OpenAIResponsesInputRoleUser2": ".openairesponsesinput_union",
    "OpenAIResponsesInputTypeFunctionCall": ".openairesponsesinput_union",
    "OpenAIResponsesInputTypeFunctionCallOutput": ".openairesponsesinput_union",
    "OpenAIResponsesInputTypeMessage1": ".openairesponsesinput_union",
    "OpenAIResponsesInputTypeMessage2": ".openairesponsesinput_union",
    "OpenAIResponsesInputUnion": ".openairesponsesinput_union",
    "OpenAIResponsesInputUnion1": ".openairesponsesinput_union",
    "OpenAIResponsesInputUnion1TypedDict": ".openairesponsesinput_union",
    "OpenAIResponsesInputUnionTypedDict": ".openairesponsesinput_union",
    "OpenAIResponsesPrompt": ".openairesponsesprompt",
    "OpenAIResponsesPromptTypedDict": ".openairesponsesprompt",
    "Variables": ".openairesponsesprompt",
    "VariablesTypedDict": ".openairesponsesprompt",
    "OpenAIResponsesReasoningConfig": ".openairesponsesreasoningconfig",
    "OpenAIResponsesReasoningConfigTypedDict": ".openairesponsesreasoningconfig",
    "OpenAIResponsesReasoningEffort": ".openairesponsesreasoningeffort",
    "OpenAIResponsesRefusalContent": ".openairesponsesrefusalcontent",
    "OpenAIResponsesRefusalContentType": ".openairesponsesrefusalcontent",
    "OpenAIResponsesRefusalContentTypedDict": ".openairesponsesrefusalcontent",
    "OpenAIResponsesResponseStatus": ".openairesponsesresponsestatus",
    "OpenAIResponsesServiceTier": ".openairesponsesservicetier",
    "OpenAIResponsesToolChoice": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceAuto": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceFunction": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceFunctionTypedDict": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceNone": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceRequired": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceTypeFunction": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceTypeWebSearchPreview": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceTypeWebSearchPreview20250311": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceTypedDict": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceUnion": ".openairesponsestoolchoice_union",
    "OpenAIResponsesToolChoiceUnionTypedDict": ".openairesponsestoolchoice_union",
    "Type": ".openairesponsestoolchoice_union",
    "TypeTypedDict": ".openairesponsestoolchoice_union",
    "OpenAIResponsesTruncation": ".openairesponsestruncation",
    "OpenResponsesEasyInputMessage": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageContentInputImage": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageContentInputImageTypedDict": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageContentType": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageContentUnion1": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageContentUnion1TypedDict": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageContentUnion2": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageContentUnion2TypedDict": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageDetail": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageRoleAssistant": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageRoleDeveloper": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageRoleSystem": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageRoleUnion": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageRoleUnionTypedDict": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageRoleUser": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageTypeMessage": ".openresponseseasyinputmessage",
    "OpenResponsesEasyInputMessageTypedDict": ".openresponseseasyinputmessage",
    "OpenResponsesErrorEvent": ".openresponseserrorevent",
    "OpenResponsesErrorEventType": ".openresponseserrorevent",
    "OpenResponsesErrorEventTypedDict": ".openresponseserrorevent",
    "OpenResponsesFunctionCallOutput": ".openresponsesfunctioncalloutput",
    "OpenResponsesFunctionCallOutputType": ".openresponsesfunctioncalloutput",
    "OpenResponsesFunctionCallOutputTypedDict": ".openresponsesfunctioncalloutput",
    "OpenResponsesFunctionToolCall": ".openresponsesfunctiontoolcall",
    "OpenResponsesFunctionToolCallType": ".openresponsesfunctiontoolcall",
    "OpenResponsesFunctionToolCallTypedDict": ".openresponsesfunctiontoolcall",
    "OpenResponsesImageGenCallCompleted": ".openresponsesimagegencallcompleted",
    "OpenResponsesImageGenCallCompletedType": ".openresponsesimagegencallcompleted",
    "OpenResponsesImageGenCallCompletedTypedDict": ".openresponsesimagegencallcompleted",
    "OpenResponsesImageGenCallGenerating": ".openresponsesimagegencallgenerating",
    "OpenResponsesImageGenCallGeneratingType": ".openresponsesimagegencallgenerating",
    "OpenResponsesImageGenCallGeneratingTypedDict": ".openresponsesimagegencallgenerating",
    "OpenResponsesImageGenCallInProgress": ".openresponsesimagegencallinprogress",
    "OpenResponsesImageGenCallInProgressType": ".openresponsesimagegencallinprogress",
    "OpenResponsesImageGenCallInProgressTypedDict": ".openresponsesimagegencallinprogress",
    "OpenResponsesImageGenCallPartialImage": ".openresponsesimagegencallpartialimage",
    "OpenResponsesImageGenCallPartialImageType": ".openresponsesimagegencallpartialimage",
    "OpenResponsesImageGenCallPartialImageTypedDict": ".openresponsesimagegencallpartialimage",
    "OpenResponsesInput": ".openresponsesinput",
    "OpenResponsesInput1": ".openresponsesinput",
    "OpenResponsesInput1TypedDict": ".openresponsesinput",
    "OpenResponsesInputTypedDict": ".openresponsesinput",
    "OpenResponsesInputMessageItem": ".openresponsesinputmessageitem",
    "OpenResponsesInputMessageItemContentInputImage": ".openresponsesinputmessageitem",
    "OpenResponsesInputMessageItemContentInputImageTypedDict": ".openresponsesinputmessageitem",
    "OpenResponsesInputMessageItemContentType": ".openresponsesinputmessageitem",
    "OpenResponsesInputMessageItemContentUnion": ".openresponsesinputmessageitem",
    "OpenResponsesInputMessageItemContentUnionTypedDict": ".openresponsesinputmessageitem",
    "OpenResponsesInputMessageItemDetail": ".openresponsesinputmessageitem",
    "OpenResponsesInputMessageItemRoleDeveloper": ".openresponsesinputmessageitem",
    "OpenResponsesInputMessageItemRoleSystem": ".openresponsesinputmessageitem",
    "OpenResponsesInputMessageItemRoleUnion": ".openresponsesinputmessageitem",
    "OpenResponsesInputMessageItemRoleUnionTypedDict": ".openresponsesinputmessageitem",
    "OpenResponsesInputMessageItemRoleUser": ".openresponsesinputmessageitem",
    "OpenResponsesInputMessageItemTypeMessage": ".openresponsesinputmessageitem",
    "OpenResponsesInputMessageItemTypedDict": ".openresponsesinputmessageitem",
    "OpenResponsesLogProbs": ".openresponseslogprobs",
    "OpenResponsesLogProbsTypedDict": ".openresponseslogprobs",
    "Object": ".openresponsesnonstreamingresponse",
    "OpenResponsesNonStreamingResponse": ".openresponsesnonstreamingresponse",
    "OpenResponsesNonStreamingResponseToolFunction": ".openresponsesnonstreamingresponse",
    "OpenResponsesNonStreamingResponseToolFunctionTypedDict": ".openresponsesnonstreamingresponse",
    "OpenResponsesNonStreamingResponseToolUnion": ".openresponsesnonstreamingresponse",
    "OpenResponsesNonStreamingResponseToolUnionTypedDict": ".openresponsesnonstreamingresponse",
    "OpenResponsesNonStreamingResponseType": ".openresponsesnonstreamingresponse",
    "OpenResponsesNonStreamingResponseTypedDict": ".openresponsesnonstreamingresponse",
    "OpenResponsesReasoning": ".openresponsesreasoning",
    "OpenResponsesReasoningFormat": ".openresponsesreasoning",
    "OpenResponsesReasoningStatusCompleted": ".openresponsesreasoning",
    "OpenResponsesReasoningStatusInProgress": ".openresponsesreasoning",
    "OpenResponsesReasoningStatusIncomplete": ".openresponsesreasoning",
    "OpenResponsesReasoningStatusUnion": ".openresponsesreasoning",
    "OpenResponsesReasoningStatusUnionTypedDict": ".openresponsesreasoning",
    "OpenResponsesReasoningType": ".openresponsesreasoning",
    "OpenResponsesReasoningTypedDict": ".openresponsesreasoning",
    "OpenResponsesReasoningConfig": ".openresponsesreasoningconfig",
    "OpenResponsesReasoningConfigTypedDict": ".openresponsesreasoningconfig",
    "OpenResponsesReasoningDeltaEvent": ".openresponsesreasoningdeltaevent",
    "OpenResponsesReasoningDeltaEventType": ".openresponsesreasoningdeltaevent",
    "OpenResponsesReasoningDeltaEventTypedDict": ".openresponsesreasoningdeltaevent",
    "OpenResponsesReasoningDoneEvent": ".openresponsesreasoningdoneevent",
    "OpenResponsesReasoningDoneEventType": ".openresponsesreasoningdoneevent",
    "OpenResponsesReasoningDoneEventTypedDict": ".openresponsesreasoningdoneevent",
    "OpenResponsesReasoningSummaryPartAddedEvent": ".openresponsesreasoningsummarypartaddedevent",
    "OpenResponsesReasoningSummaryPartAddedEventType": ".openresponsesreasoningsummarypartaddedevent",
    "OpenResponsesReasoningSummaryPartAddedEventTypedDict": ".openresponsesreasoningsummarypartaddedevent",
    "OpenResponsesReasoningSummaryTextDeltaEvent": ".openresponsesreasoningsummarytextdeltaevent",
    "OpenResponsesReasoningSummaryTextDeltaEventType": ".openresponsesreasoningsummarytextdeltaevent",
    "OpenResponsesReasoningSummaryTextDeltaEventTypedDict": ".openresponsesreasoningsummarytextdeltaevent",
    "OpenResponsesReasoningSummaryTextDoneEvent": ".openresponsesreasoningsummarytextdoneevent",
    "OpenResponsesReasoningSummaryTextDoneEventType": ".openresponsesreasoningsummarytextdoneevent",
    "OpenResponsesReasoningSummaryTextDoneEventTypedDict": ".openresponsesreasoningsummarytextdoneevent",
    "IDAutoRouter": ".openresponsesrequest",
    "IDFileParser": ".openresponsesrequest",
    "IDModeration": ".openresponsesrequest",
    "IDResponseHealing": ".openresponsesrequest",
    "IDWeb": ".openresponsesrequest",
    "OpenResponsesRequest": ".openresponsesrequest",
    "OpenResponsesRequestIgnore": ".openresponsesrequest",
    "OpenResponsesRequestIgnoreTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestImageConfig": ".openresponsesrequest",
    "OpenResponsesRequestImageConfigTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestMaxPrice": ".openresponsesrequest",
    "OpenResponsesRequestMaxPriceTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestOnly": ".openresponsesrequest",
    "OpenResponsesRequestOnlyTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestOrder": ".openresponsesrequest",
    "OpenResponsesRequestOrderTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestPluginAutoRouter": ".openresponsesrequest",
    "OpenResponsesRequestPluginAutoRouterTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestPluginFileParser": ".openresponsesrequest",
    "OpenResponsesRequestPluginFileParserTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestPluginModeration": ".openresponsesrequest",
    "OpenResponsesRequestPluginModerationTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestPluginResponseHealing": ".openresponsesrequest",
    "OpenResponsesRequestPluginResponseHealingTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestPluginUnion": ".openresponsesrequest",
    "OpenResponsesRequestPluginUnionTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestPluginWeb": ".openresponsesrequest",
    "OpenResponsesRequestPluginWebTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestProvider": ".openresponsesrequest",
    "OpenResponsesRequestProviderTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestSort": ".openresponsesrequest",
    "OpenResponsesRequestSortTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestToolFunction": ".openresponsesrequest",
    "OpenResponsesRequestToolFunctionTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestToolUnion": ".openresponsesrequest",
    "OpenResponsesRequestToolUnionTypedDict": ".openresponsesrequest",
    "OpenResponsesRequestType": ".openresponsesrequest",
    "OpenResponsesRequestTypedDict": ".openresponsesrequest",
    "ServiceTier": ".openresponsesrequest",
    "Truncation": ".openresponsesrequest",
    "OpenResponsesResponseText": ".openresponsesresponsetext",
    "OpenResponsesResponseTextTypedDict": ".openresponsesresponsetext",
    "OpenResponsesResponseTextVerbosity": ".openresponsesresponsetext",
    "OpenResponsesStreamEvent": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseCompleted": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseCompletedTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseContentPartAdded": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseContentPartAddedTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseContentPartDone": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseContentPartDoneTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseCreated": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseCreatedTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseFailed": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseFailedTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseFunctionCallArgumentsDelta": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseFunctionCallArgumentsDeltaTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseFunctionCallArgumentsDone": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseFunctionCallArgumentsDoneTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseInProgress": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseInProgressTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseIncomplete": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseIncompleteTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseOutputItemAdded": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseOutputItemAddedTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseOutputItemDone": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseOutputItemDoneTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseOutputTextAnnotationAdded": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseOutputTextAnnotationAddedTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseOutputTextDelta": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseOutputTextDeltaTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseOutputTextDone": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseOutputTextDoneTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseReasoningSummaryPartDone": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseReasoningSummaryPartDoneTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseRefusalDelta": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseRefusalDeltaTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseRefusalDone": ".openresponsesstreamevent",
    "OpenResponsesStreamEventResponseRefusalDoneTypedDict": ".openresponsesstreamevent",
    "OpenResponsesStreamEventTypedDict": ".openresponsesstreamevent",
    "Part1": ".openresponsesstreamevent",
    "Part1TypedDict": ".openresponsesstreamevent",
    "Part2": ".openresponsesstreamevent",
    "Part2TypedDict": ".openresponsesstreamevent",
    "TypeResponseCompleted": ".openresponsesstreamevent",
    "TypeResponseContentPartAdded": ".openresponsesstreamevent",
    "TypeResponseContentPartDone": ".openresponsesstreamevent",
    "TypeResponseCreated": ".openresponsesstreamevent",
    "TypeResponseFailed": ".openresponsesstreamevent",
    "TypeResponseFunctionCallArgumentsDelta": ".openresponsesstreamevent",
    "TypeResponseFunctionCallArgumentsDone": ".openresponsesstreamevent",
    "TypeResponseInProgress": ".openresponsesstreamevent",
    "TypeResponseIncomplete": ".openresponsesstreamevent",
    "TypeResponseOutputItemAdded": ".openresponsesstreamevent",
    "TypeResponseOutputItemDone": ".openresponsesstreamevent",
    "TypeResponseOutputTextAnnotationAdded": ".openresponsesstreamevent",
    "TypeResponseOutputTextDelta": ".openresponsesstreamevent",
    "TypeResponseOutputTextDone": ".openresponsesstreamevent",
    "TypeResponseReasoningSummaryPartDone": ".openresponsesstreamevent",
    "TypeResponseRefusalDelta": ".openresponsesstreamevent",
    "TypeResponseRefusalDone": ".openresponsesstreamevent",
    "OpenResponsesTopLogprobs": ".openresponsestoplogprobs",
    "OpenResponsesTopLogprobsTypedDict": ".openresponsestoplogprobs",
    "CostDetails": ".openresponsesusage",
    "CostDetailsTypedDict": ".openresponsesusage",
    "InputTokensDetails": ".openresponsesusage",
    "InputTokensDetailsTypedDict": ".openresponsesusage",
    "OpenResponsesUsage": ".openresponsesusage",
    "OpenResponsesUsageTypedDict": ".openresponsesusage",
    "OutputTokensDetails": ".openresponsesusage",
    "OutputTokensDetailsTypedDict": ".openresponsesusage",
    "OpenResponsesWebSearch20250826Tool": ".openresponseswebsearch20250826tool",
    "OpenResponsesWebSearch20250826ToolFilters": ".openresponseswebsearch20250826tool",
    "OpenResponsesWebSearch20250826ToolFiltersTypedDict": ".openresponseswebsearch20250826tool",
    "OpenResponsesWebSearch20250826ToolType": ".openresponseswebsearch20250826tool",
    "OpenResponsesWebSearch20250826ToolTypedDict": ".openresponseswebsearch20250826tool",
    "OpenResponsesWebSearchPreview20250311Tool": ".openresponseswebsearchpreview20250311tool",
    "OpenResponsesWebSearchPreview20250311ToolType": ".openresponseswebsearchpreview20250311tool",
    "OpenResponsesWebSearchPreview20250311ToolTypedDict": ".openresponseswebsearchpreview20250311tool",
    "OpenResponsesWebSearchPreviewTool": ".openresponseswebsearchpreviewtool",
    "OpenResponsesWebSearchPreviewToolType": ".openresponseswebsearchpreviewtool",
    "OpenResponsesWebSearchPreviewToolTypedDict": ".openresponseswebsearchpreviewtool",
    "OpenResponsesWebSearchTool": ".openresponseswebsearchtool",
    "OpenResponsesWebSearchToolFilters": ".openresponseswebsearchtool",
    "OpenResponsesWebSearchToolFiltersTypedDict": ".openresponseswebsearchtool",
    "OpenResponsesWebSearchToolType": ".openresponseswebsearchtool",
    "OpenResponsesWebSearchToolTypedDict": ".openresponseswebsearchtool",
    "OutputItemImageGenerationCall": ".outputitemimagegenerationcall",
    "OutputItemImageGenerationCallType": ".outputitemimagegenerationcall",
    "OutputItemImageGenerationCallTypedDict": ".outputitemimagegenerationcall",
    "OutputMessage": ".outputmessage",
    "OutputMessageContent": ".outputmessage",
    "OutputMessageContentTypedDict": ".outputmessage",
    "OutputMessageRole": ".outputmessage",
    "OutputMessageStatusCompleted": ".outputmessage",
    "OutputMessageStatusInProgress": ".outputmessage",
    "OutputMessageStatusIncomplete": ".outputmessage",
    "OutputMessageStatusUnion": ".outputmessage",
    "OutputMessageStatusUnionTypedDict": ".outputmessage",
    "OutputMessageType": ".outputmessage",
    "OutputMessageTypedDict": ".outputmessage",
    "OutputModality": ".outputmodality",
    "Parameter": ".parameter",
    "PayloadTooLargeResponseErrorData": ".payloadtoolargeresponseerrordata",
    "PayloadTooLargeResponseErrorDataTypedDict": ".payloadtoolargeresponseerrordata",
    "PaymentRequiredResponseErrorData": ".paymentrequiredresponseerrordata",
    "PaymentRequiredResponseErrorDataTypedDict": ".paymentrequiredresponseerrordata",
    "PDFParserEngine": ".pdfparserengine",
    "PDFParserOptions": ".pdfparseroptions",
    "PDFParserOptionsTypedDict": ".pdfparseroptions",
    "PercentileLatencyCutoffs": ".percentilelatencycutoffs",
    "PercentileLatencyCutoffsTypedDict": ".percentilelatencycutoffs",
    "PercentileStats": ".percentilestats",
    "PercentileStatsTypedDict": ".percentilestats",
    "PercentileThroughputCutoffs": ".percentilethroughputcutoffs",
    "PercentileThroughputCutoffsTypedDict": ".percentilethroughputcutoffs",
    "PerRequestLimits": ".perrequestlimits",
    "PerRequestLimitsTypedDict": ".perrequestlimits",
    "PreferredMaxLatency": ".preferredmaxlatency",
    "PreferredMaxLatencyTypedDict": ".preferredmaxlatency",
    "PreferredMinThroughput": ".preferredminthroughput",
    "PreferredMinThroughputTypedDict": ".preferredminthroughput",
    "ProviderName": ".providername",
    "ProviderOverloadedResponseErrorData": ".provideroverloadedresponseerrordata",
    "ProviderOverloadedResponseErrorDataTypedDict": ".provideroverloadedresponseerrordata",
    "ProviderPreferences": ".providerpreferences",
    "ProviderPreferencesIgnore": ".providerpreferences",
    "ProviderPreferencesIgnoreTypedDict": ".providerpreferences",
    "ProviderPreferencesMaxPrice": ".providerpreferences",
    "ProviderPreferencesMaxPriceTypedDict": ".providerpreferences",
    "ProviderPreferencesOnly": ".providerpreferences",
    "ProviderPreferencesOnlyTypedDict": ".providerpreferences",
    "ProviderPreferencesOrder": ".providerpreferences",
    "ProviderPreferencesOrderTypedDict": ".providerpreferences",
    "ProviderPreferencesPartition": ".providerpreferences",
    "ProviderPreferencesProviderSort": ".providerpreferences",
    "ProviderPreferencesProviderSortConfig": ".providerpreferences",
    "ProviderPreferencesProviderSortConfigTypedDict": ".providerpreferences",
    "ProviderPreferencesSortUnion": ".providerpreferences",
    "ProviderPreferencesSortUnionTypedDict": ".providerpreferences",
    "ProviderPreferencesTypedDict": ".providerpreferences",
    "ProviderSortConfigEnum": ".providerpreferences",
    "ProviderSortConfigUnion": ".providerpreferences",
    "ProviderSortConfigUnionTypedDict": ".providerpreferences",
    "SortEnum": ".providerpreferences",
    "ProviderSort": ".providersort",
    "Partition": ".providersortconfig",
    "ProviderSortConfig": ".providersortconfig",
    "ProviderSortConfigTypedDict": ".providersortconfig",
    "ProviderSortUnion": ".providersortunion",
    "ProviderSortUnionTypedDict": ".providersortunion",
    "Pricing": ".publicendpoint",
    "PricingTypedDict": ".publicendpoint",
    "PublicEndpoint": ".publicendpoint",
    "PublicEndpointQuantization": ".publicendpoint",
    "PublicEndpointTypedDict": ".publicendpoint",
    "PublicPricing": ".publicpricing",
    "PublicPricingTypedDict": ".publicpricing",
    "Quantization": ".quantization",
    "ReasoningSummaryText": ".reasoningsummarytext",
    "ReasoningSummaryTextType": ".reasoningsummarytext",
    "ReasoningSummaryTextTypedDict": ".reasoningsummarytext",
    "ReasoningSummaryVerbosity": ".reasoningsummaryverbosity",
    "ReasoningTextContent": ".reasoningtextcontent",
    "ReasoningTextContentType": ".reasoningtextcontent",
    "ReasoningTextContentTypedDict": ".reasoningtextcontent",
    "RequestTimeoutResponseErrorData": ".requesttimeoutresponseerrordata",
    "RequestTimeoutResponseErrorDataTypedDict": ".requesttimeoutresponseerrordata",
    "ResponseFormatJSONSchema": ".responseformatjsonschema",
    "ResponseFormatJSONSchemaTypedDict": ".responseformatjsonschema",
    "ResponseFormatTextConfig": ".responseformattextconfig",
    "ResponseFormatTextConfigTypedDict": ".responseformattextconfig",
    "ResponseFormatTextGrammar": ".responseformattextgrammar",
    "ResponseFormatTextGrammarTypedDict": ".responseformattextgrammar",
    "ResponseInputAudio": ".responseinputaudio",
    "ResponseInputAudioFormat": ".responseinputaudio",
    "ResponseInputAudioInputAudio": ".responseinputaudio",
    "ResponseInputAudioInputAudioTypedDict": ".responseinputaudio",
    "ResponseInputAudioType": ".responseinputaudio",
    "ResponseInputAudioTypedDict": ".responseinputaudio",
    "ResponseInputFile": ".responseinputfile",
    "ResponseInputFileType": ".responseinputfile",
    "ResponseInputFileTypedDict": ".responseinputfile",
    "ResponseInputImage": ".responseinputimage",
    "ResponseInputImageDetail": ".responseinputimage",
    "ResponseInputImageType": ".responseinputimage",
    "ResponseInputImageTypedDict": ".responseinputimage",
    "ResponseInputText": ".responseinputtext",
    "ResponseInputTextType": ".responseinputtext",
    "ResponseInputTextTypedDict": ".responseinputtext",
    "ResponseInputVideo": ".responseinputvideo",
    "ResponseInputVideoType": ".responseinputvideo",
    "ResponseInputVideoTypedDict": ".responseinputvideo",
    "Logprob": ".responseoutputtext",
    "LogprobTypedDict": ".responseoutputtext",
    "ResponseOutputText": ".responseoutputtext",
    "ResponseOutputTextTopLogprob": ".responseoutputtext",
    "ResponseOutputTextTopLogprobTypedDict": ".responseoutputtext",
    "ResponseOutputTextType": ".responseoutputtext",
    "ResponseOutputTextTypedDict": ".responseoutputtext",
    "CodeEnum": ".responseserrorfield",
    "ResponsesErrorField": ".responseserrorfield",
    "ResponsesErrorFieldTypedDict": ".responseserrorfield",
    "ResponsesFormatJSONObject": ".responsesformatjsonobject",
    "ResponsesFormatJSONObjectType": ".responsesformatjsonobject",
    "ResponsesFormatJSONObjectTypedDict": ".responsesformatjsonobject",
    "ResponsesFormatText": ".responsesformattext",
    "ResponsesFormatTextType": ".responsesformattext",
    "ResponsesFormatTextTypedDict": ".responsesformattext",
    "ResponsesFormatTextJSONSchemaConfig": ".responsesformattextjsonschemaconfig",
    "ResponsesFormatTextJSONSchemaConfigType": ".responsesformattextjsonschemaconfig",
    "ResponsesFormatTextJSONSchemaConfigTypedDict": ".responsesformattextjsonschemaconfig",
    "ResponsesImageGenerationCall": ".responsesimagegenerationcall",
    "ResponsesImageGenerationCallType": ".responsesimagegenerationcall",
    "ResponsesImageGenerationCallTypedDict": ".responsesimagegenerationcall",
    "ResponsesOutputItem": ".responsesoutputitem",
    "ResponsesOutputItemTypedDict": ".responsesoutputitem",
    "ResponsesOutputItemFileSearchCall": ".responsesoutputitemfilesearchcall",
    "ResponsesOutputItemFileSearchCallType": ".responsesoutputitemfilesearchcall",
    "ResponsesOutputItemFileSearchCallTypedDict": ".responsesoutputitemfilesearchcall",
    "ResponsesOutputItemFunctionCall": ".responsesoutputitemfunctioncall",
    "ResponsesOutputItemFunctionCallStatusCompleted": ".responsesoutputitemfunctioncall",
    "ResponsesOutputItemFunctionCallStatusInProgress": ".responsesoutputitemfunctioncall",
    "ResponsesOutputItemFunctionCallStatusIncomplete": ".responsesoutputitemfunctioncall",
    "ResponsesOutputItemFunctionCallStatusUnion": ".responsesoutputitemfunctioncall",
    "ResponsesOutputItemFunctionCallStatusUnionTypedDict": ".responsesoutputitemfunctioncall",
    "ResponsesOutputItemFunctionCallType": ".responsesoutputitemfunctioncall",
    "ResponsesOutputItemFunctionCallTypedDict": ".responsesoutputitemfunctioncall",
    "ResponsesOutputItemReasoning": ".responsesoutputitemreasoning",
    "ResponsesOutputItemReasoningFormat": ".responsesoutputitemreasoning",
    "ResponsesOutputItemReasoningStatusCompleted": ".responsesoutputitemreasoning",
    "ResponsesOutputItemReasoningStatusInProgress": ".responsesoutputitemreasoning",
    "ResponsesOutputItemReasoningStatusIncomplete": ".responsesoutputitemreasoning",
    "ResponsesOutputItemReasoningStatusUnion": ".responsesoutputitemreasoning",
    "ResponsesOutputItemReasoningStatusUnionTypedDict": ".responsesoutputitemreasoning",
    "ResponsesOutputItemReasoningType": ".responsesoutputitemreasoning",
    "ResponsesOutputItemReasoningTypedDict": ".responsesoutputitemreasoning",
    "ResponsesOutputMessage": ".responsesoutputmessage",
    "ResponsesOutputMessageContent": ".responsesoutputmessage",
    "ResponsesOutputMessageContentTypedDict": ".responsesoutputmessage",
    "ResponsesOutputMessageRole": ".responsesoutputmessage",
    "ResponsesOutputMessageStatusCompleted": ".responsesoutputmessage",
    "ResponsesOutputMessageStatusInProgress": ".responsesoutputmessage",
    "ResponsesOutputMessageStatusIncomplete": ".responsesoutputmessage",
    "ResponsesOutputMessageStatusUnion": ".responsesoutputmessage",
    "ResponsesOutputMessageStatusUnionTypedDict": ".responsesoutputmessage",
    "ResponsesOutputMessageType": ".responsesoutputmessage",
    "ResponsesOutputMessageTypedDict": ".responsesoutputmessage",
    "ResponsesOutputModality": ".responsesoutputmodality",
    "ResponsesSearchContextSize": ".responsessearchcontextsize",
    "ResponsesWebSearchCallOutput": ".responseswebsearchcalloutput",
    "ResponsesWebSearchCallOutputType": ".responseswebsearchcalloutput",
    "ResponsesWebSearchCallOutputTypedDict": ".responseswebsearchcalloutput",
    "ResponsesWebSearchUserLocation": ".responseswebsearchuserlocation",
    "ResponsesWebSearchUserLocationType": ".responseswebsearchuserlocation",
    "ResponsesWebSearchUserLocationTypedDict": ".responseswebsearchuserlocation",
    "ResponseTextConfig": ".responsetextconfig",
    "ResponseTextConfigTypedDict": ".responsetextconfig",
    "ResponseTextConfigVerbosity": ".responsetextconfig",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "ServiceUnavailableResponseErrorData": ".serviceunavailableresponseerrordata",
    "ServiceUnavailableResponseErrorDataTypedDict": ".serviceunavailableresponseerrordata",
    "SystemMessage": ".systemmessage",
    "SystemMessageContent": ".systemmessage",
    "SystemMessageContentTypedDict": ".systemmessage",
    "SystemMessageTypedDict": ".systemmessage",
    "ToolCallStatus": ".toolcallstatus",
    "ToolDefinitionJSON": ".tooldefinitionjson",
    "ToolDefinitionJSONFunction": ".tooldefinitionjson",
    "ToolDefinitionJSONFunctionTypedDict": ".tooldefinitionjson",
    "ToolDefinitionJSONTypedDict": ".tooldefinitionjson",
    "ToolResponseMessage": ".toolresponsemessage",
    "ToolResponseMessageContent": ".toolresponsemessage",
    "ToolResponseMessageContentTypedDict": ".toolresponsemessage",
    "ToolResponseMessageTypedDict": ".toolresponsemessage",
    "TooManyRequestsResponseErrorData": ".toomanyrequestsresponseerrordata",
    "TooManyRequestsResponseErrorDataTypedDict": ".toomanyrequestsresponseerrordata",
    "TopProviderInfo": ".topproviderinfo",
    "TopProviderInfoTypedDict": ".topproviderinfo",
    "UnauthorizedResponseErrorData": ".unauthorizedresponseerrordata",
    "UnauthorizedResponseErrorDataTypedDict": ".unauthorizedresponseerrordata",
    "UnprocessableEntityResponseErrorData": ".unprocessableentityresponseerrordata",
    "UnprocessableEntityResponseErrorDataTypedDict": ".unprocessableentityresponseerrordata",
    "URLCitation": ".urlcitation",
    "URLCitationType": ".urlcitation",
    "URLCitationTypedDict": ".urlcitation",
    "UserMessage": ".usermessage",
    "UserMessageContent": ".usermessage",
    "UserMessageContentTypedDict": ".usermessage",
    "UserMessageTypedDict": ".usermessage",
    "WebSearchEngine": ".websearchengine",
    "WebSearchPreviewToolUserLocation": ".websearchpreviewtooluserlocation",
    "WebSearchPreviewToolUserLocationType": ".websearchpreviewtooluserlocation",
    "WebSearchPreviewToolUserLocationTypedDict": ".websearchpreviewtooluserlocation",
    "WebSearchStatus": ".websearchstatus",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)
